Class: Google::Apis::SqladminV1::BackupRun
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::BackupRun
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
A BackupRun resource.
Instance Attribute Summary collapse
-
#backup_kind ⇒ String
Specifies the kind of backup, PHYSICAL or DEFAULT_SNAPSHOT.
-
#database_version ⇒ String
Output only.
-
#description ⇒ String
The description of this run, only applicable to on-demand backups.
-
#disk_encryption_configuration ⇒ Google::Apis::SqladminV1::DiskEncryptionConfiguration
Disk encryption configuration for an instance.
-
#disk_encryption_status ⇒ Google::Apis::SqladminV1::DiskEncryptionStatus
Disk encryption status for an instance.
-
#end_time ⇒ String
The time the backup operation completed in UTC timezone in RFC 3339 format, for example
2012-11-15T16:19:00.094Z. -
#enqueued_time ⇒ String
The time the run was enqueued in UTC timezone in RFC 3339 format, for example
2012-11-15T16:19:00.094Z. -
#error ⇒ Google::Apis::SqladminV1::OperationError
Database instance operation error.
-
#id ⇒ Fixnum
The identifier for this backup run.
-
#instance ⇒ String
Name of the database instance.
-
#kind ⇒ String
This is always
sql#backupRun. -
#location ⇒ String
Location of the backups.
-
#max_chargeable_bytes ⇒ Fixnum
Output only.
-
#self_link ⇒ String
The URI of this resource.
-
#start_time ⇒ String
The time the backup operation actually started in UTC timezone in RFC 3339 format, for example `2012-11-15T16:19:00.
-
#status ⇒ String
The status of this run.
-
#time_zone ⇒ String
Backup time zone to prevent restores to an instance with a different time zone.
-
#type ⇒ String
The type of this run; can be either "AUTOMATED" or "ON_DEMAND" or "FINAL".
-
#window_start_time ⇒ String
The start time of the backup window during which this the backup was attempted in RFC 3339 format, for example
2012- 11-15T16:19:00.094Z.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupRun
constructor
A new instance of BackupRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupRun
Returns a new instance of BackupRun.
635 636 637 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 635 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_kind ⇒ String
Specifies the kind of backup, PHYSICAL or DEFAULT_SNAPSHOT.
Corresponds to the JSON property backupKind
533 534 535 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 533 def backup_kind @backup_kind end |
#database_version ⇒ String
Output only. The instance database version at the time this backup was made.
Corresponds to the JSON property databaseVersion
538 539 540 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 538 def database_version @database_version end |
#description ⇒ String
The description of this run, only applicable to on-demand backups.
Corresponds to the JSON property description
543 544 545 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 543 def description @description end |
#disk_encryption_configuration ⇒ Google::Apis::SqladminV1::DiskEncryptionConfiguration
Disk encryption configuration for an instance.
Corresponds to the JSON property diskEncryptionConfiguration
548 549 550 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 548 def disk_encryption_configuration @disk_encryption_configuration end |
#disk_encryption_status ⇒ Google::Apis::SqladminV1::DiskEncryptionStatus
Disk encryption status for an instance.
Corresponds to the JSON property diskEncryptionStatus
553 554 555 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 553 def disk_encryption_status @disk_encryption_status end |
#end_time ⇒ String
The time the backup operation completed in UTC timezone in RFC 3339 format, for example 2012-11-15T16:19:00.094Z.
Corresponds to the JSON property endTime
559 560 561 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 559 def end_time @end_time end |
#enqueued_time ⇒ String
The time the run was enqueued in UTC timezone in RFC 3339 format, for example 2012-11-15T16:19:00.094Z.
Corresponds to the JSON property enqueuedTime
565 566 567 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 565 def enqueued_time @enqueued_time end |
#error ⇒ Google::Apis::SqladminV1::OperationError
Database instance operation error.
Corresponds to the JSON property error
570 571 572 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 570 def error @error end |
#id ⇒ Fixnum
The identifier for this backup run. Unique only for a specific Cloud SQL
instance.
Corresponds to the JSON property id
576 577 578 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 576 def id @id end |
#instance ⇒ String
Name of the database instance.
Corresponds to the JSON property instance
581 582 583 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 581 def instance @instance end |
#kind ⇒ String
This is always sql#backupRun.
Corresponds to the JSON property kind
586 587 588 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 586 def kind @kind end |
#location ⇒ String
Location of the backups.
Corresponds to the JSON property location
591 592 593 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 591 def location @location end |
#max_chargeable_bytes ⇒ Fixnum
Output only. The maximum chargeable bytes for the backup.
Corresponds to the JSON property maxChargeableBytes
596 597 598 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 596 def max_chargeable_bytes @max_chargeable_bytes end |
#self_link ⇒ String
The URI of this resource.
Corresponds to the JSON property selfLink
601 602 603 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 601 def self_link @self_link end |
#start_time ⇒ String
The time the backup operation actually started in UTC timezone in RFC 3339 format, for example 2012-11-15T16:19:00.
094Z.
Corresponds to the JSON property startTime
608 609 610 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 608 def start_time @start_time end |
#status ⇒ String
The status of this run.
Corresponds to the JSON property status
613 614 615 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 613 def status @status end |
#time_zone ⇒ String
Backup time zone to prevent restores to an instance with a different time zone.
Now relevant only for SQL Server.
Corresponds to the JSON property timeZone
619 620 621 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 619 def time_zone @time_zone end |
#type ⇒ String
The type of this run; can be either "AUTOMATED" or "ON_DEMAND" or "FINAL".
This field defaults to "ON_DEMAND" and is ignored, when specified for insert
requests.
Corresponds to the JSON property type
626 627 628 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 626 def type @type end |
#window_start_time ⇒ String
The start time of the backup window during which this the backup was attempted
in RFC 3339 format, for example 2012-
11-15T16:19:00.094Z.
Corresponds to the JSON property windowStartTime
633 634 635 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 633 def window_start_time @window_start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 640 def update!(**args) @backup_kind = args[:backup_kind] if args.key?(:backup_kind) @database_version = args[:database_version] if args.key?(:database_version) @description = args[:description] if args.key?(:description) @disk_encryption_configuration = args[:disk_encryption_configuration] if args.key?(:disk_encryption_configuration) @disk_encryption_status = args[:disk_encryption_status] if args.key?(:disk_encryption_status) @end_time = args[:end_time] if args.key?(:end_time) @enqueued_time = args[:enqueued_time] if args.key?(:enqueued_time) @error = args[:error] if args.key?(:error) @id = args[:id] if args.key?(:id) @instance = args[:instance] if args.key?(:instance) @kind = args[:kind] if args.key?(:kind) @location = args[:location] if args.key?(:location) @max_chargeable_bytes = args[:max_chargeable_bytes] if args.key?(:max_chargeable_bytes) @self_link = args[:self_link] if args.key?(:self_link) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) @time_zone = args[:time_zone] if args.key?(:time_zone) @type = args[:type] if args.key?(:type) @window_start_time = args[:window_start_time] if args.key?(:window_start_time) end |