Class: Google::Apis::SqladminV1::CloneContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Database instance clone context.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloneContext

Returns a new instance of CloneContext.



808
809
810
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 808

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocated_ip_rangeString

The name of the allocated ip range for the private ip Cloud SQL instance. For example: "google-managed-services-default". If set, the cloned instance ip will be created in the allocated range. The range name must comply with RFC 1035. Specifically, the name must be 1- 63 characters long and match the regular expression a-z?. Reserved for future use. Corresponds to the JSON property allocatedIpRange

Returns:

  • (String)


738
739
740
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 738

def allocated_ip_range
  @allocated_ip_range
end

#bin_log_coordinatesGoogle::Apis::SqladminV1::BinLogCoordinates

Binary log coordinates. Corresponds to the JSON property binLogCoordinates



743
744
745
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 743

def bin_log_coordinates
  @bin_log_coordinates
end

#database_namesArray<String>

(SQL Server only) Clone only the specified databases from the source instance. Clone all databases if empty. Corresponds to the JSON property databaseNames

Returns:

  • (Array<String>)


749
750
751
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 749

def database_names
  @database_names
end

#destination_instance_nameString

Required. Name of the Cloud SQL instance to be created as a clone. Corresponds to the JSON property destinationInstanceName

Returns:

  • (String)


754
755
756
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 754

def destination_instance_name
  @destination_instance_name
end

#destination_networkString

Optional. The fully qualified URI of the VPC network to which the cloned instance will be connected via private services access for private IP. For example:projects/my-network-project/global/networks/my-network. This field is only required for cross-project cloning. Corresponds to the JSON property destinationNetwork

Returns:

  • (String)


762
763
764
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 762

def destination_network
  @destination_network
end

#destination_projectString

Optional. The project ID of the destination project where the cloned instance will be created. To perform a cross-project clone, this field is required. If not specified, the clone is created in the same project as the source instance. Corresponds to the JSON property destinationProject

Returns:

  • (String)


769
770
771
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 769

def destination_project
  @destination_project
end

#kindString

This is always sql#cloneContext. Corresponds to the JSON property kind

Returns:

  • (String)


774
775
776
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 774

def kind
  @kind
end

#pitr_timestamp_msFixnum

Reserved for future use. Corresponds to the JSON property pitrTimestampMs

Returns:

  • (Fixnum)


779
780
781
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 779

def pitr_timestamp_ms
  @pitr_timestamp_ms
end

#point_in_timeString

Timestamp, if specified, identifies the time to which the source instance is cloned. Corresponds to the JSON property pointInTime

Returns:

  • (String)


785
786
787
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 785

def point_in_time
  @point_in_time
end

#preferred_secondary_zoneString

Optional. Copy clone and point-in-time recovery clone of a regional instance in the specified zones. If not specified, clone to the same secondary zone as the source instance. This value cannot be the same as the preferred_zone field. This field applies to all DB types. Corresponds to the JSON property preferredSecondaryZone

Returns:

  • (String)


793
794
795
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 793

def preferred_secondary_zone
  @preferred_secondary_zone
end

#preferred_zoneString

Optional. Copy clone and point-in-time recovery clone of an instance to the specified zone. If no zone is specified, clone to the same primary zone as the source instance. This field applies to all DB types. Corresponds to the JSON property preferredZone

Returns:

  • (String)


800
801
802
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 800

def preferred_zone
  @preferred_zone
end

#source_instance_deletion_timeString

The timestamp used to identify the time when the source instance is deleted. If this instance is deleted, then you must set the timestamp. Corresponds to the JSON property sourceInstanceDeletionTime

Returns:

  • (String)


806
807
808
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 806

def source_instance_deletion_time
  @source_instance_deletion_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



813
814
815
816
817
818
819
820
821
822
823
824
825
826
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 813

def update!(**args)
  @allocated_ip_range = args[:allocated_ip_range] if args.key?(:allocated_ip_range)
  @bin_log_coordinates = args[:bin_log_coordinates] if args.key?(:bin_log_coordinates)
  @database_names = args[:database_names] if args.key?(:database_names)
  @destination_instance_name = args[:destination_instance_name] if args.key?(:destination_instance_name)
  @destination_network = args[:destination_network] if args.key?(:destination_network)
  @destination_project = args[:destination_project] if args.key?(:destination_project)
  @kind = args[:kind] if args.key?(:kind)
  @pitr_timestamp_ms = args[:pitr_timestamp_ms] if args.key?(:pitr_timestamp_ms)
  @point_in_time = args[:point_in_time] if args.key?(:point_in_time)
  @preferred_secondary_zone = args[:preferred_secondary_zone] if args.key?(:preferred_secondary_zone)
  @preferred_zone = args[:preferred_zone] if args.key?(:preferred_zone)
  @source_instance_deletion_time = args[:source_instance_deletion_time] if args.key?(:source_instance_deletion_time)
end