Class: Google::Apis::SqladminV1::ConnectionPoolFlags

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Connection pool flags for Cloud SQL instances managed connection pool configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectionPoolFlags

Returns a new instance of ConnectionPoolFlags.



1051
1052
1053
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1051

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. The name of the flag. Corresponds to the JSON property name

Returns:

  • (String)


1043
1044
1045
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1043

def name
  @name
end

#valueString

Required. The value of the flag. Boolean flags are set to on for true and off for false. This field must be omitted if the flag doesn't take a value. Corresponds to the JSON property value

Returns:

  • (String)


1049
1050
1051
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1049

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1056
1057
1058
1059
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1056

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end