Class: Google::Apis::SqladminV1::DatabaseFlags

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Database flags for Cloud SQL instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseFlags

Returns a new instance of DatabaseFlags.



1178
1179
1180
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the flag. These flags are passed at instance startup, so include both server options and system variables. Flags are specified with underscores, not hyphens. For more information, see Configuring Database Flags in the Cloud SQL documentation. Corresponds to the JSON property name

Returns:

  • (String)


1170
1171
1172
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1170

def name
  @name
end

#valueString

The value of the flag. Boolean flags are set to on for true and off for false. This field must be omitted if the flag doesn't take a value. Corresponds to the JSON property value

Returns:

  • (String)


1176
1177
1178
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1176

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1183
1184
1185
1186
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1183

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end