Class: Google::Apis::SqladminV1::ExportContext::CsvExportOptions
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::ExportContext::CsvExportOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Options for exporting data as CSV. MySQL and PostgreSQL instances only.
Instance Attribute Summary collapse
-
#escape_character ⇒ String
Specifies the character that should appear before a data character that needs to be escaped.
-
#fields_terminated_by ⇒ String
Specifies the character that separates columns within each row (line) of the file.
-
#lines_terminated_by ⇒ String
This is used to separate lines.
-
#quote_character ⇒ String
Specifies the quoting character to be used when a data value is quoted.
-
#select_query ⇒ String
The select query used to extract the data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CsvExportOptions
constructor
A new instance of CsvExportOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CsvExportOptions
Returns a new instance of CsvExportOptions.
2146 2147 2148 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2146 def initialize(**args) update!(**args) end |
Instance Attribute Details
#escape_character ⇒ String
Specifies the character that should appear before a data character that needs
to be escaped.
Corresponds to the JSON property escapeCharacter
2122 2123 2124 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2122 def escape_character @escape_character end |
#fields_terminated_by ⇒ String
Specifies the character that separates columns within each row (line) of the
file.
Corresponds to the JSON property fieldsTerminatedBy
2128 2129 2130 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2128 def fields_terminated_by @fields_terminated_by end |
#lines_terminated_by ⇒ String
This is used to separate lines. If a line does not contain all fields, the
rest of the columns are set to their default values.
Corresponds to the JSON property linesTerminatedBy
2134 2135 2136 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2134 def lines_terminated_by @lines_terminated_by end |
#quote_character ⇒ String
Specifies the quoting character to be used when a data value is quoted.
Corresponds to the JSON property quoteCharacter
2139 2140 2141 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2139 def quote_character @quote_character end |
#select_query ⇒ String
The select query used to extract the data.
Corresponds to the JSON property selectQuery
2144 2145 2146 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2144 def select_query @select_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2151 2152 2153 2154 2155 2156 2157 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2151 def update!(**args) @escape_character = args[:escape_character] if args.key?(:escape_character) @fields_terminated_by = args[:fields_terminated_by] if args.key?(:fields_terminated_by) @lines_terminated_by = args[:lines_terminated_by] if args.key?(:lines_terminated_by) @quote_character = args[:quote_character] if args.key?(:quote_character) @select_query = args[:select_query] if args.key?(:select_query) end |