Class: Google::Apis::SqladminV1::ExportContext::SqlExportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Options for exporting data as SQL statements.

Defined Under Namespace

Classes: MysqlExportOptions, PostgresExportOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlExportOptions

Returns a new instance of SqlExportOptions.



2210
2211
2212
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mysql_export_optionsGoogle::Apis::SqladminV1::ExportContext::SqlExportOptions::MysqlExportOptions

Options for exporting from MySQL. Corresponds to the JSON property mysqlExportOptions



2179
2180
2181
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2179

def mysql_export_options
  @mysql_export_options
end

#parallelBoolean Also known as: parallel?

Optional. Whether or not the export should be parallel. Corresponds to the JSON property parallel

Returns:

  • (Boolean)


2184
2185
2186
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2184

def parallel
  @parallel
end

#postgres_export_optionsGoogle::Apis::SqladminV1::ExportContext::SqlExportOptions::PostgresExportOptions

Options for exporting from a Cloud SQL for PostgreSQL instance. Corresponds to the JSON property postgresExportOptions



2190
2191
2192
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2190

def postgres_export_options
  @postgres_export_options
end

#schema_onlyBoolean Also known as: schema_only?

Export only schemas. Corresponds to the JSON property schemaOnly

Returns:

  • (Boolean)


2195
2196
2197
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2195

def schema_only
  @schema_only
end

#tablesArray<String>

Tables to export, or that were exported, from the specified database. If you specify tables, specify one and only one database. For PostgreSQL instances, you can specify only one table. Corresponds to the JSON property tables

Returns:

  • (Array<String>)


2203
2204
2205
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2203

def tables
  @tables
end

#threadsFixnum

Optional. The number of threads to use for parallel export. Corresponds to the JSON property threads

Returns:

  • (Fixnum)


2208
2209
2210
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2208

def threads
  @threads
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2215
2216
2217
2218
2219
2220
2221
2222
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2215

def update!(**args)
  @mysql_export_options = args[:mysql_export_options] if args.key?(:mysql_export_options)
  @parallel = args[:parallel] if args.key?(:parallel)
  @postgres_export_options = args[:postgres_export_options] if args.key?(:postgres_export_options)
  @schema_only = args[:schema_only] if args.key?(:schema_only)
  @tables = args[:tables] if args.key?(:tables)
  @threads = args[:threads] if args.key?(:threads)
end