Class: Google::Apis::SqladminV1::ExportContext::TdeExportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Optional. Export parameters specific to SQL Server TDE certificates

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TdeExportOptions

Returns a new instance of TdeExportOptions.



2305
2306
2307
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_pathString

Required. Path to the TDE certificate public key in the form gs://bucketName/ fileName. The instance must have write access to the bucket. Applicable only for SQL Server instances. Corresponds to the JSON property certificatePath

Returns:

  • (String)


2286
2287
2288
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2286

def certificate_path
  @certificate_path
end

#nameString

Required. Certificate name. Applicable only for SQL Server instances. Corresponds to the JSON property name

Returns:

  • (String)


2291
2292
2293
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2291

def name
  @name
end

#private_key_passwordString

Required. Password that encrypts the private key. Corresponds to the JSON property privateKeyPassword

Returns:

  • (String)


2296
2297
2298
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2296

def private_key_password
  @private_key_password
end

#private_key_pathString

Required. Path to the TDE certificate private key in the form gs://bucketName/ fileName. The instance must have write access to the location. Applicable only for SQL Server instances. Corresponds to the JSON property privateKeyPath

Returns:

  • (String)


2303
2304
2305
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2303

def private_key_path
  @private_key_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2310
2311
2312
2313
2314
2315
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2310

def update!(**args)
  @certificate_path = args[:certificate_path] if args.key?(:certificate_path)
  @name = args[:name] if args.key?(:name)
  @private_key_password = args[:private_key_password] if args.key?(:private_key_password)
  @private_key_path = args[:private_key_path] if args.key?(:private_key_path)
end