Class: Google::Apis::SqladminV1::GenerateEphemeralCertRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Ephemeral certificate creation request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateEphemeralCertRequest

Returns a new instance of GenerateEphemeralCertRequest.



2578
2579
2580
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2578

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_tokenString

Optional. Access token to include in the signed certificate. Corresponds to the JSON property access_token

Returns:

  • (String)


2561
2562
2563
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2561

def access_token
  @access_token
end

#public_keyString

PEM encoded public key to include in the signed certificate. Corresponds to the JSON property public_key

Returns:

  • (String)


2566
2567
2568
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2566

def public_key
  @public_key
end

#read_timeString

Optional. Optional snapshot read timestamp to trade freshness for performance. Corresponds to the JSON property readTime

Returns:

  • (String)


2571
2572
2573
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2571

def read_time
  @read_time
end

#valid_durationString

Optional. If set, it will contain the cert valid duration. Corresponds to the JSON property validDuration

Returns:

  • (String)


2576
2577
2578
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2576

def valid_duration
  @valid_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2583
2584
2585
2586
2587
2588
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2583

def update!(**args)
  @access_token = args[:access_token] if args.key?(:access_token)
  @public_key = args[:public_key] if args.key?(:public_key)
  @read_time = args[:read_time] if args.key?(:read_time)
  @valid_duration = args[:valid_duration] if args.key?(:valid_duration)
end