Class: Google::Apis::SqladminV1::ImportContext::TdeImportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Optional. Import parameters specific to SQL Server TDE certificates

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TdeImportOptions

Returns a new instance of TdeImportOptions.



2946
2947
2948
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2946

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_pathString

Required. Path to the TDE certificate public key in the form gs://bucketName/ fileName. The instance must have read access to the file. Applicable only for SQL Server instances. Corresponds to the JSON property certificatePath

Returns:

  • (String)


2927
2928
2929
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2927

def certificate_path
  @certificate_path
end

#nameString

Required. Certificate name. Applicable only for SQL Server instances. Corresponds to the JSON property name

Returns:

  • (String)


2932
2933
2934
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2932

def name
  @name
end

#private_key_passwordString

Required. Password that encrypts the private key. Corresponds to the JSON property privateKeyPassword

Returns:

  • (String)


2937
2938
2939
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2937

def private_key_password
  @private_key_password
end

#private_key_pathString

Required. Path to the TDE certificate private key in the form gs://bucketName/ fileName. The instance must have read access to the file. Applicable only for SQL Server instances. Corresponds to the JSON property privateKeyPath

Returns:

  • (String)


2944
2945
2946
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2944

def private_key_path
  @private_key_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2951
2952
2953
2954
2955
2956
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2951

def update!(**args)
  @certificate_path = args[:certificate_path] if args.key?(:certificate_path)
  @name = args[:name] if args.key?(:name)
  @private_key_password = args[:private_key_password] if args.key?(:private_key_password)
  @private_key_path = args[:private_key_path] if args.key?(:private_key_path)
end