Class: Google::Apis::SqladminV1::IpMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Database instance IP mapping

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpMapping

Returns a new instance of IpMapping.



3678
3679
3680
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_addressString

The IP address assigned. Corresponds to the JSON property ipAddress

Returns:

  • (String)


3661
3662
3663
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3661

def ip_address
  @ip_address
end

#time_to_retireString

The due time for this IP to be retired in RFC 3339 format, for example 2012-11-15T16:19:00.094Z. This field is only available when the IP is scheduled to be retired. Corresponds to the JSON property timeToRetire

Returns:

  • (String)


3668
3669
3670
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3668

def time_to_retire
  @time_to_retire
end

#typeString

The type of this IP address. A PRIMARY address is a public address that can accept incoming connections. A PRIVATE address is a private address that can accept incoming connections. An OUTGOING address is the source address of connections originating from the instance, if supported. Corresponds to the JSON property type

Returns:

  • (String)


3676
3677
3678
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3676

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3683
3684
3685
3686
3687
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3683

def update!(**args)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @time_to_retire = args[:time_to_retire] if args.key?(:time_to_retire)
  @type = args[:type] if args.key?(:type)
end