Class: Google::Apis::SqladminV1::Message

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Represents a notice or warning message from the database.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Message

Returns a new instance of Message.



3804
3805
3806
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messageString

The full message string. For PostgreSQL, this is a formatted string that may include severity, code, and the notice/warning message. For MySQL, this contains the warning message. Corresponds to the JSON property message

Returns:

  • (String)


3796
3797
3798
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3796

def message
  @message
end

#severityString

The severity of the message (e.g., "NOTICE" for PostgreSQL, "WARNING" for MySQL). Corresponds to the JSON property severity

Returns:

  • (String)


3802
3803
3804
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3802

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3809
3810
3811
3812
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3809

def update!(**args)
  @message = args[:message] if args.key?(:message)
  @severity = args[:severity] if args.key?(:severity)
end