Class: Google::Apis::SqladminV1::OnPremisesConfiguration
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::OnPremisesConfiguration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
On-premises instance configuration.
Instance Attribute Summary collapse
-
#ca_certificate ⇒ String
PEM representation of the trusted CA's x509 certificate.
-
#client_certificate ⇒ String
PEM representation of the replica's x509 certificate.
-
#client_key ⇒ String
PEM representation of the replica's private key.
-
#dms_managed ⇒ Boolean
(also: #dms_managed?)
Output only.
-
#dump_file_path ⇒ String
The dump file to create the Cloud SQL replica.
-
#host_port ⇒ String
The host and port of the on-premises instance in host:port format Corresponds to the JSON property
hostPort. -
#kind ⇒ String
This is always
sql#onPremisesConfiguration. -
#password ⇒ String
The password for connecting to on-premises instance.
-
#selected_objects ⇒ Array<Google::Apis::SqladminV1::SelectedObjects>
Optional.
-
#source_instance ⇒ Google::Apis::SqladminV1::InstanceReference
Reference to another Cloud SQL instance.
-
#ssl_option ⇒ String
Optional.
-
#username ⇒ String
The username for connecting to on-premises instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OnPremisesConfiguration
constructor
A new instance of OnPremisesConfiguration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OnPremisesConfiguration
Returns a new instance of OnPremisesConfiguration.
4037 4038 4039 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4037 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ca_certificate ⇒ String
PEM representation of the trusted CA's x509 certificate.
Corresponds to the JSON property caCertificate
3976 3977 3978 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3976 def ca_certificate @ca_certificate end |
#client_certificate ⇒ String
PEM representation of the replica's x509 certificate.
Corresponds to the JSON property clientCertificate
3981 3982 3983 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3981 def client_certificate @client_certificate end |
#client_key ⇒ String
PEM representation of the replica's private key. The corresponding public key
is encoded in the client's certificate.
Corresponds to the JSON property clientKey
3987 3988 3989 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3987 def client_key @client_key end |
#dms_managed ⇒ Boolean Also known as: dms_managed?
Output only. Indicates whether the resource is managed by Database Migration
Service.
Corresponds to the JSON property dmsManaged
3993 3994 3995 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3993 def dms_managed @dms_managed end |
#dump_file_path ⇒ String
The dump file to create the Cloud SQL replica.
Corresponds to the JSON property dumpFilePath
3999 4000 4001 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3999 def dump_file_path @dump_file_path end |
#host_port ⇒ String
The host and port of the on-premises instance in host:port format
Corresponds to the JSON property hostPort
4004 4005 4006 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4004 def host_port @host_port end |
#kind ⇒ String
This is always sql#onPremisesConfiguration.
Corresponds to the JSON property kind
4009 4010 4011 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4009 def kind @kind end |
#password ⇒ String
The password for connecting to on-premises instance.
Corresponds to the JSON property password
4014 4015 4016 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4014 def password @password end |
#selected_objects ⇒ Array<Google::Apis::SqladminV1::SelectedObjects>
Optional. A list of objects that the user selects for replication from an
external source instance.
Corresponds to the JSON property selectedObjects
4020 4021 4022 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4020 def selected_objects @selected_objects end |
#source_instance ⇒ Google::Apis::SqladminV1::InstanceReference
Reference to another Cloud SQL instance.
Corresponds to the JSON property sourceInstance
4025 4026 4027 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4025 def source_instance @source_instance end |
#ssl_option ⇒ String
Optional. SSL option for replica connection to the on-premises source.
Corresponds to the JSON property sslOption
4030 4031 4032 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4030 def ssl_option @ssl_option end |
#username ⇒ String
The username for connecting to on-premises instance.
Corresponds to the JSON property username
4035 4036 4037 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4035 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4042 def update!(**args) @ca_certificate = args[:ca_certificate] if args.key?(:ca_certificate) @client_certificate = args[:client_certificate] if args.key?(:client_certificate) @client_key = args[:client_key] if args.key?(:client_key) @dms_managed = args[:dms_managed] if args.key?(:dms_managed) @dump_file_path = args[:dump_file_path] if args.key?(:dump_file_path) @host_port = args[:host_port] if args.key?(:host_port) @kind = args[:kind] if args.key?(:kind) @password = args[:password] if args.key?(:password) @selected_objects = args[:selected_objects] if args.key?(:selected_objects) @source_instance = args[:source_instance] if args.key?(:source_instance) @ssl_option = args[:ssl_option] if args.key?(:ssl_option) @username = args[:username] if args.key?(:username) end |