Class: Google::Apis::SqladminV1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#cancel_requested ⇒ Boolean
(also: #cancel_requested?)
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#status_detail ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
4262 4263 4264 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4262 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
4226 4227 4228 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4226 def api_version @api_version end |
#cancel_requested ⇒ Boolean Also known as: cancel_requested?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have been cancelled successfully have google.
longrunning.Operation.error value with a google.rpc.Status.code of 1,
corresponding to Code.CANCELLED.
Corresponds to the JSON property cancelRequested
4234 4235 4236 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4234 def cancel_requested @cancel_requested end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
4240 4241 4242 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4240 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
4245 4246 4247 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4245 def end_time @end_time end |
#status_detail ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusDetail
4250 4251 4252 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4250 def status_detail @status_detail end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
4255 4256 4257 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4255 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
4260 4261 4262 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4260 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4267 4268 4269 4270 4271 4272 4273 4274 4275 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4267 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @cancel_requested = args[:cancel_requested] if args.key?(:cancel_requested) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @status_detail = args[:status_detail] if args.key?(:status_detail) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |