Class: Google::Apis::SqladminV1::PerformanceCaptureConfig
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::PerformanceCaptureConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Performance capture configuration.
Instance Attribute Summary collapse
-
#cpu_utilization_threshold_percent ⇒ Fixnum
Optional.
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#history_list_length_threshold_count ⇒ Fixnum
Optional.
-
#memory_usage_threshold_percent ⇒ Fixnum
Optional.
-
#probe_threshold ⇒ Fixnum
Optional.
-
#probing_interval_seconds ⇒ Fixnum
Optional.
-
#running_threads_threshold ⇒ Fixnum
Optional.
-
#seconds_behind_source_threshold ⇒ Fixnum
Optional.
-
#semaphore_wait_threshold_count ⇒ Fixnum
Optional.
-
#transaction_duration_threshold ⇒ Fixnum
Optional.
-
#transaction_kill_excluded_user_hosts ⇒ Array<String>
Optional.
-
#transaction_kill_threshold_seconds ⇒ Fixnum
Optional.
-
#transaction_kill_type ⇒ String
Optional.
-
#transaction_lock_wait_threshold_count ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PerformanceCaptureConfig
constructor
A new instance of PerformanceCaptureConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PerformanceCaptureConfig
Returns a new instance of PerformanceCaptureConfig.
4558 4559 4560 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpu_utilization_threshold_percent ⇒ Fixnum
Optional. Specifies the minimum percentage of CPU utilization to trigger the
performance capture. Valid integers range from 10 to 99. Enter 0 to
disable the check.
Corresponds to the JSON property cpuUtilizationThresholdPercent
4465 4466 4467 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4465 def cpu_utilization_threshold_percent @cpu_utilization_threshold_percent end |
#enabled ⇒ Boolean Also known as: enabled?
Optional. Enables or disables the performance capture feature.
Corresponds to the JSON property enabled
4470 4471 4472 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4470 def enabled @enabled end |
#history_list_length_threshold_count ⇒ Fixnum
Optional. Specifies the minimum number of undo log entries in the history list
length to trigger the performance capture. Valid integers range from 10000
to 10000000. Enter 0 to disable the check.
Corresponds to the JSON property historyListLengthThresholdCount
4478 4479 4480 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4478 def history_list_length_threshold_count @history_list_length_threshold_count end |
#memory_usage_threshold_percent ⇒ Fixnum
Optional. Specifies the minimum percentage of memory usage to trigger the
performance capture. Valid integers range from 10 to 99. Enter 0 to
disable the check.
Corresponds to the JSON property memoryUsageThresholdPercent
4485 4486 4487 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4485 def memory_usage_threshold_percent @memory_usage_threshold_percent end |
#probe_threshold ⇒ Fixnum
Optional. Specifies the minimum number of consecutive probe threshold that
triggers performance capture.
Corresponds to the JSON property probeThreshold
4491 4492 4493 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4491 def probe_threshold @probe_threshold end |
#probing_interval_seconds ⇒ Fixnum
Optional. Specifies the interval in seconds between consecutive probes that
check if any trigger condition thresholds have been reached.
Corresponds to the JSON property probingIntervalSeconds
4497 4498 4499 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4497 def probing_interval_seconds @probing_interval_seconds end |
#running_threads_threshold ⇒ Fixnum
Optional. Specifies the minimum number of MySQL Threads_running to trigger
the performance capture on the primary instance.
Corresponds to the JSON property runningThreadsThreshold
4503 4504 4505 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4503 def running_threads_threshold @running_threads_threshold end |
#seconds_behind_source_threshold ⇒ Fixnum
Optional. Specifies the minimum number of seconds replica must be lagging
behind primary instance to trigger the performance capture on replica.
Corresponds to the JSON property secondsBehindSourceThreshold
4509 4510 4511 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4509 def seconds_behind_source_threshold @seconds_behind_source_threshold end |
#semaphore_wait_threshold_count ⇒ Fixnum
Optional. Specifies the minimum allowed number of semaphore waits to trigger
the performance capture. Valid integers range from 10 to 10000. Enter 0
to disable the check.
Corresponds to the JSON property semaphoreWaitThresholdCount
4516 4517 4518 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4516 def semaphore_wait_threshold_count @semaphore_wait_threshold_count end |
#transaction_duration_threshold ⇒ Fixnum
Optional. Specifies the amount of time in seconds that a transaction needs to
have been open before the watcher starts recording it.
Corresponds to the JSON property transactionDurationThreshold
4522 4523 4524 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4522 def transaction_duration_threshold @transaction_duration_threshold end |
#transaction_kill_excluded_user_hosts ⇒ Array<String>
Optional. Specifies a customer-defined list of users to exclude from
transaction termination. Entries can be in the format 'user@host' or just '
user'. A standalone 'user' implies 'user@%', excluding the user from any host.
Wildcard '%' is allowed in the host part of the 'user@host' format. Example: [
"app_user", "db_admin@10.1.2.3", "report_user@%"]
Corresponds to the JSON property transactionKillExcludedUserHosts
4531 4532 4533 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4531 def transaction_kill_excluded_user_hosts @transaction_kill_excluded_user_hosts end |
#transaction_kill_threshold_seconds ⇒ Fixnum
Optional. Specifies the amount of time in seconds that a transaction needs to
have been open before the watcher starts terminating it. Valid integers range
from 60 to 604800 (7 days). Enter 0 to disable. If enabled (i.e., > 0),
this value must be greater than or equal to transaction_duration_threshold.
Configurations where 0 < transaction_kill_threshold_seconds <
transaction_duration_threshold will be rejected.
Corresponds to the JSON property transactionKillThresholdSeconds
4541 4542 4543 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4541 def transaction_kill_threshold_seconds @transaction_kill_threshold_seconds end |
#transaction_kill_type ⇒ String
Optional. Determines which transactions are allowed to be terminated when they
exceed transaction_kill_threshold_seconds. This allows protecting write-
heavy transactions from auto-termination if desired. Defaults to
READ_ONLY_TRANSACTIONS if unspecified.
Corresponds to the JSON property transactionKillType
4549 4550 4551 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4549 def transaction_kill_type @transaction_kill_type end |
#transaction_lock_wait_threshold_count ⇒ Fixnum
Optional. Specifies the minimum allowed number of transactions in lock wait
state to trigger the performance capture. Valid integers range from 10 to
10000. Enter 0 to disable the check.
Corresponds to the JSON property transactionLockWaitThresholdCount
4556 4557 4558 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4556 def transaction_lock_wait_threshold_count @transaction_lock_wait_threshold_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 4578 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4563 def update!(**args) @cpu_utilization_threshold_percent = args[:cpu_utilization_threshold_percent] if args.key?(:cpu_utilization_threshold_percent) @enabled = args[:enabled] if args.key?(:enabled) @history_list_length_threshold_count = args[:history_list_length_threshold_count] if args.key?(:history_list_length_threshold_count) @memory_usage_threshold_percent = args[:memory_usage_threshold_percent] if args.key?(:memory_usage_threshold_percent) @probe_threshold = args[:probe_threshold] if args.key?(:probe_threshold) @probing_interval_seconds = args[:probing_interval_seconds] if args.key?(:probing_interval_seconds) @running_threads_threshold = args[:running_threads_threshold] if args.key?(:running_threads_threshold) @seconds_behind_source_threshold = args[:seconds_behind_source_threshold] if args.key?(:seconds_behind_source_threshold) @semaphore_wait_threshold_count = args[:semaphore_wait_threshold_count] if args.key?(:semaphore_wait_threshold_count) @transaction_duration_threshold = args[:transaction_duration_threshold] if args.key?(:transaction_duration_threshold) @transaction_kill_excluded_user_hosts = args[:transaction_kill_excluded_user_hosts] if args.key?(:transaction_kill_excluded_user_hosts) @transaction_kill_threshold_seconds = args[:transaction_kill_threshold_seconds] if args.key?(:transaction_kill_threshold_seconds) @transaction_kill_type = args[:transaction_kill_type] if args.key?(:transaction_kill_type) @transaction_lock_wait_threshold_count = args[:transaction_lock_wait_threshold_count] if args.key?(:transaction_lock_wait_threshold_count) end |