Class: Google::Apis::SqladminV1::PoolNodeConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Details of a single read pool node of a read pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PoolNodeConfig

Returns a new instance of PoolNodeConfig.



4691
4692
4693
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_nameString

Output only. The DNS name of the read pool node. Corresponds to the JSON property dnsName

Returns:

  • (String)


4649
4650
4651
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4649

def dns_name
  @dns_name
end

#dns_namesArray<Google::Apis::SqladminV1::DnsNameMapping>

Output only. The list of DNS names used by this read pool node. Corresponds to the JSON property dnsNames



4654
4655
4656
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4654

def dns_names
  @dns_names
end

#gce_zoneString

Output only. The zone of the read pool node. Corresponds to the JSON property gceZone

Returns:

  • (String)


4659
4660
4661
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4659

def gce_zone
  @gce_zone
end

#ip_addressesArray<Google::Apis::SqladminV1::IpMapping>

Output only. Mappings containing IP addresses that can be used to connect to the read pool node. Corresponds to the JSON property ipAddresses



4665
4666
4667
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4665

def ip_addresses
  @ip_addresses
end

#nameString

Output only. The name of the read pool node, to be used for retrieving metrics and logs. Corresponds to the JSON property name

Returns:

  • (String)


4671
4672
4673
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4671

def name
  @name
end

#psc_auto_connectionsArray<Google::Apis::SqladminV1::PscAutoConnectionConfig>

Output only. The list of settings for requested automatically-setup Private Service Connect (PSC) consumer endpoints that can be used to connect to this read pool node. Corresponds to the JSON property pscAutoConnections



4678
4679
4680
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4678

def psc_auto_connections
  @psc_auto_connections
end

Output only. The Private Service Connect (PSC) service attachment of the read pool node. Corresponds to the JSON property pscServiceAttachmentLink

Returns:

  • (String)


4684
4685
4686
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4684

def psc_service_attachment_link
  @psc_service_attachment_link
end

#stateString

Output only. The current state of the read pool node. Corresponds to the JSON property state

Returns:

  • (String)


4689
4690
4691
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4689

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4696
4697
4698
4699
4700
4701
4702
4703
4704
4705
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4696

def update!(**args)
  @dns_name = args[:dns_name] if args.key?(:dns_name)
  @dns_names = args[:dns_names] if args.key?(:dns_names)
  @gce_zone = args[:gce_zone] if args.key?(:gce_zone)
  @ip_addresses = args[:ip_addresses] if args.key?(:ip_addresses)
  @name = args[:name] if args.key?(:name)
  @psc_auto_connections = args[:psc_auto_connections] if args.key?(:psc_auto_connections)
  @psc_service_attachment_link = args[:psc_service_attachment_link] if args.key?(:psc_service_attachment_link)
  @state = args[:state] if args.key?(:state)
end