Class: Google::Apis::SqladminV1::PscConfig
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::PscConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
PSC settings for a Cloud SQL instance.
Instance Attribute Summary collapse
-
#allowed_consumer_projects ⇒ Array<String>
Optional.
-
#network_attachment_uri ⇒ String
Optional.
-
#psc_auto_connection_policy_enabled ⇒ Boolean
(also: #psc_auto_connection_policy_enabled?)
Optional.
-
#psc_auto_connections ⇒ Array<Google::Apis::SqladminV1::PscAutoConnectionConfig>
Optional.
-
#psc_auto_dns_enabled ⇒ Boolean
(also: #psc_auto_dns_enabled?)
Optional.
-
#psc_enabled ⇒ Boolean
(also: #psc_enabled?)
Whether PSC connectivity is enabled for this instance.
-
#psc_write_endpoint_dns_enabled ⇒ Boolean
(also: #psc_write_endpoint_dns_enabled?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscConfig
constructor
A new instance of PscConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscConfig
Returns a new instance of PscConfig.
4933 4934 4935 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4933 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_consumer_projects ⇒ Array<String>
Optional. The list of consumer projects that are allow-listed for PSC
connections to this instance. This instance can be connected to with PSC from
any network in these projects. Each consumer project in this list may be
represented by a project number (numeric) or by a project id (alphanumeric).
Corresponds to the JSON property allowedConsumerProjects
4884 4885 4886 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4884 def allowed_consumer_projects @allowed_consumer_projects end |
#network_attachment_uri ⇒ String
Optional. The network attachment of the consumer network that the Private
Service Connect enabled Cloud SQL instance is authorized to connect via PSC
interface. format: projects/PROJECT/regions/REGION/networkAttachments/ID
Corresponds to the JSON property networkAttachmentUri
4891 4892 4893 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4891 def @network_attachment_uri end |
#psc_auto_connection_policy_enabled ⇒ Boolean Also known as: psc_auto_connection_policy_enabled?
Optional. Whether to set up the PSC service connection policy automatically.
Corresponds to the JSON property pscAutoConnectionPolicyEnabled
4896 4897 4898 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4896 def psc_auto_connection_policy_enabled @psc_auto_connection_policy_enabled end |
#psc_auto_connections ⇒ Array<Google::Apis::SqladminV1::PscAutoConnectionConfig>
Optional. The list of settings for requested Private Service Connect consumer
endpoints that can be used to connect to this Cloud SQL instance.
Corresponds to the JSON property pscAutoConnections
4903 4904 4905 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4903 def psc_auto_connections @psc_auto_connections end |
#psc_auto_dns_enabled ⇒ Boolean Also known as: psc_auto_dns_enabled?
Optional. Indicates whether Private Service Connect DNS automation is enabled
for this instance. When enabled, Cloud SQL provisions a universal DNS record
across all networks configured with Private Service Connect auto-connections.
This will default to true for new instances when Private Service Connect is
enabled.
Corresponds to the JSON property pscAutoDnsEnabled
4912 4913 4914 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4912 def psc_auto_dns_enabled @psc_auto_dns_enabled end |
#psc_enabled ⇒ Boolean Also known as: psc_enabled?
Whether PSC connectivity is enabled for this instance.
Corresponds to the JSON property pscEnabled
4918 4919 4920 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4918 def psc_enabled @psc_enabled end |
#psc_write_endpoint_dns_enabled ⇒ Boolean Also known as: psc_write_endpoint_dns_enabled?
Optional. Indicates whether Private Service Connect write endpoint DNS
automation is enabled for this instance. When enabled, Cloud SQL provisions a
universal global DNS record across all networks configured with Private
Service Connect auto-connections that points to the cluster primary instance.
This feature is only supported for Enterprise Plus edition. This will default
to true for new Enterprise Plus instances when psc_auto_dns_enabled is
enabled.
Corresponds to the JSON property pscWriteEndpointDnsEnabled
4930 4931 4932 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4930 def psc_write_endpoint_dns_enabled @psc_write_endpoint_dns_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4938 4939 4940 4941 4942 4943 4944 4945 4946 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4938 def update!(**args) @allowed_consumer_projects = args[:allowed_consumer_projects] if args.key?(:allowed_consumer_projects) @network_attachment_uri = args[:network_attachment_uri] if args.key?(:network_attachment_uri) @psc_auto_connection_policy_enabled = args[:psc_auto_connection_policy_enabled] if args.key?(:psc_auto_connection_policy_enabled) @psc_auto_connections = args[:psc_auto_connections] if args.key?(:psc_auto_connections) @psc_auto_dns_enabled = args[:psc_auto_dns_enabled] if args.key?(:psc_auto_dns_enabled) @psc_enabled = args[:psc_enabled] if args.key?(:psc_enabled) @psc_write_endpoint_dns_enabled = args[:psc_write_endpoint_dns_enabled] if args.key?(:psc_write_endpoint_dns_enabled) end |