Class: Google::Apis::SqladminV1::RestoreBackupContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::RestoreBackupContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Database instance restore from backup context. Backup context contains source instance id and project id.
Instance Attribute Summary collapse
-
#backup_run_id ⇒ Fixnum
The ID of the backup run to restore from.
-
#instance_id ⇒ String
The ID of the instance that the backup was taken from.
-
#kind ⇒ String
This is always
sql#restoreBackupContext. -
#project ⇒ String
The full project ID of the source instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RestoreBackupContext
constructor
A new instance of RestoreBackupContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RestoreBackupContext
Returns a new instance of RestoreBackupContext.
5174 5175 5176 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5174 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_run_id ⇒ Fixnum
The ID of the backup run to restore from.
Corresponds to the JSON property backupRunId
5157 5158 5159 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5157 def backup_run_id @backup_run_id end |
#instance_id ⇒ String
The ID of the instance that the backup was taken from.
Corresponds to the JSON property instanceId
5162 5163 5164 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5162 def instance_id @instance_id end |
#kind ⇒ String
This is always sql#restoreBackupContext.
Corresponds to the JSON property kind
5167 5168 5169 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5167 def kind @kind end |
#project ⇒ String
The full project ID of the source instance.
Corresponds to the JSON property project
5172 5173 5174 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5172 def project @project end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5179 5180 5181 5182 5183 5184 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5179 def update!(**args) @backup_run_id = args[:backup_run_id] if args.key?(:backup_run_id) @instance_id = args[:instance_id] if args.key?(:instance_id) @kind = args[:kind] if args.key?(:kind) @project = args[:project] if args.key?(:project) end |