Class: Google::Apis::SqladminV1::SqlInstancesGetLatestRecoveryTimeResponse
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::SqlInstancesGetLatestRecoveryTimeResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Instance get latest recovery time response.
Instance Attribute Summary collapse
-
#earliest_recovery_time ⇒ String
Timestamp, identifies the earliest recovery time of the source instance.
-
#kind ⇒ String
This is always
sql#getLatestRecoveryTime. -
#latest_recovery_time ⇒ String
Timestamp, identifies the latest recovery time of the source instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlInstancesGetLatestRecoveryTimeResponse
constructor
A new instance of SqlInstancesGetLatestRecoveryTimeResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlInstancesGetLatestRecoveryTimeResponse
Returns a new instance of SqlInstancesGetLatestRecoveryTimeResponse.
5864 5865 5866 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5864 def initialize(**args) update!(**args) end |
Instance Attribute Details
#earliest_recovery_time ⇒ String
Timestamp, identifies the earliest recovery time of the source instance.
Corresponds to the JSON property earliestRecoveryTime
5852 5853 5854 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5852 def earliest_recovery_time @earliest_recovery_time end |
#kind ⇒ String
This is always sql#getLatestRecoveryTime.
Corresponds to the JSON property kind
5857 5858 5859 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5857 def kind @kind end |
#latest_recovery_time ⇒ String
Timestamp, identifies the latest recovery time of the source instance.
Corresponds to the JSON property latestRecoveryTime
5862 5863 5864 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5862 def latest_recovery_time @latest_recovery_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5869 5870 5871 5872 5873 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5869 def update!(**args) @earliest_recovery_time = args[:earliest_recovery_time] if args.key?(:earliest_recovery_time) @kind = args[:kind] if args.key?(:kind) @latest_recovery_time = args[:latest_recovery_time] if args.key?(:latest_recovery_time) end |