Class: Google::Apis::SqladminV1::SqlSubOperationType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

The sub operation type based on the operation type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlSubOperationType

Returns a new instance of SqlSubOperationType.



6101
6102
6103
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6101

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maintenance_typeString

The type of maintenance to be performed on the instance. Corresponds to the JSON property maintenanceType

Returns:

  • (String)


6099
6100
6101
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6099

def maintenance_type
  @maintenance_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6106
6107
6108
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6106

def update!(**args)
  @maintenance_type = args[:maintenance_type] if args.key?(:maintenance_type)
end