Class: Google::Apis::SqladminV1::SslCert
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::SslCert
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
SslCerts Resource
Instance Attribute Summary collapse
-
#cert ⇒ String
PEM representation.
-
#cert_serial_number ⇒ String
Serial number, as extracted from the certificate.
-
#common_name ⇒ String
User supplied name.
-
#create_time ⇒ String
The time when the certificate was created in RFC 3339 format, for example
2012-11-15T16:19:00.094ZCorresponds to the JSON propertycreateTime. -
#expiration_time ⇒ String
The time when the certificate expires in RFC 3339 format, for example
2012-11-15T16:19:00.094Z. -
#instance ⇒ String
Name of the database instance.
-
#kind ⇒ String
This is always
sql#sslCert. -
#self_link ⇒ String
The URI of this resource.
-
#sha1_fingerprint ⇒ String
Sha1 Fingerprint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCert
constructor
A new instance of SslCert.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCert
Returns a new instance of SslCert.
6348 6349 6350 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6348 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cert ⇒ String
PEM representation.
Corresponds to the JSON property cert
6304 6305 6306 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6304 def cert @cert end |
#cert_serial_number ⇒ String
Serial number, as extracted from the certificate.
Corresponds to the JSON property certSerialNumber
6309 6310 6311 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6309 def cert_serial_number @cert_serial_number end |
#common_name ⇒ String
User supplied name. Constrained to [a-zA-Z.-_ ]+.
Corresponds to the JSON property commonName
6314 6315 6316 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6314 def common_name @common_name end |
#create_time ⇒ String
The time when the certificate was created in RFC 3339 format, for example 2012-11-15T16:19:00.094Z
Corresponds to the JSON property createTime
6320 6321 6322 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6320 def create_time @create_time end |
#expiration_time ⇒ String
The time when the certificate expires in RFC 3339 format, for example 2012-11-15T16:19:00.094Z.
Corresponds to the JSON property expirationTime
6326 6327 6328 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6326 def expiration_time @expiration_time end |
#instance ⇒ String
Name of the database instance.
Corresponds to the JSON property instance
6331 6332 6333 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6331 def instance @instance end |
#kind ⇒ String
This is always sql#sslCert.
Corresponds to the JSON property kind
6336 6337 6338 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6336 def kind @kind end |
#self_link ⇒ String
The URI of this resource.
Corresponds to the JSON property selfLink
6341 6342 6343 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6341 def self_link @self_link end |
#sha1_fingerprint ⇒ String
Sha1 Fingerprint.
Corresponds to the JSON property sha1Fingerprint
6346 6347 6348 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6346 def sha1_fingerprint @sha1_fingerprint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6353 def update!(**args) @cert = args[:cert] if args.key?(:cert) @cert_serial_number = args[:cert_serial_number] if args.key?(:cert_serial_number) @common_name = args[:common_name] if args.key?(:common_name) @create_time = args[:create_time] if args.key?(:create_time) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @instance = args[:instance] if args.key?(:instance) @kind = args[:kind] if args.key?(:kind) @self_link = args[:self_link] if args.key?(:self_link) @sha1_fingerprint = args[:sha1_fingerprint] if args.key?(:sha1_fingerprint) end |