Class: Google::Apis::SqladminV1::SslCertsInsertResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

SslCert insert response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertsInsertResponse

Returns a new instance of SslCertsInsertResponse.



6463
6464
6465
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6463

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_certGoogle::Apis::SqladminV1::SslCertDetail

SslCertDetail. Corresponds to the JSON property clientCert



6444
6445
6446
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6444

def client_cert
  @client_cert
end

#kindString

This is always sql#sslCertsInsert. Corresponds to the JSON property kind

Returns:

  • (String)


6449
6450
6451
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6449

def kind
  @kind
end

#operationGoogle::Apis::SqladminV1::Operation

An Operation resource. For successful operations that return an Operation resource, only the fields relevant to the operation are populated in the resource. Corresponds to the JSON property operation



6456
6457
6458
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6456

def operation
  @operation
end

#server_ca_certGoogle::Apis::SqladminV1::SslCert

SslCerts Resource Corresponds to the JSON property serverCaCert



6461
6462
6463
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6461

def server_ca_cert
  @server_ca_cert
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6468
6469
6470
6471
6472
6473
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6468

def update!(**args)
  @client_cert = args[:client_cert] if args.key?(:client_cert)
  @kind = args[:kind] if args.key?(:kind)
  @operation = args[:operation] if args.key?(:operation)
  @server_ca_cert = args[:server_ca_cert] if args.key?(:server_ca_cert)
end