Class: Google::Apis::SqladminV1::Tier
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::Tier
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
A Google Cloud SQL service tier resource.
Instance Attribute Summary collapse
-
#disk_quota ⇒ Fixnum
The maximum disk size of this tier in bytes.
-
#kind ⇒ String
This is always
sql#tier. -
#ram ⇒ Fixnum
The maximum RAM usage of this tier in bytes.
-
#region ⇒ Array<String>
The applicable regions for this tier.
-
#tier ⇒ String
An identifier for the machine type, for example,
db-custom-1-3840.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Tier
constructor
A new instance of Tier.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Tier
Returns a new instance of Tier.
6606 6607 6608 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disk_quota ⇒ Fixnum
The maximum disk size of this tier in bytes.
Corresponds to the JSON property DiskQuota
6583 6584 6585 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6583 def disk_quota @disk_quota end |
#kind ⇒ String
This is always sql#tier.
Corresponds to the JSON property kind
6593 6594 6595 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6593 def kind @kind end |
#ram ⇒ Fixnum
The maximum RAM usage of this tier in bytes.
Corresponds to the JSON property RAM
6588 6589 6590 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6588 def ram @ram end |
#region ⇒ Array<String>
The applicable regions for this tier.
Corresponds to the JSON property region
6598 6599 6600 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6598 def region @region end |
#tier ⇒ String
An identifier for the machine type, for example, db-custom-1-3840. For
related information, see Pricing.
Corresponds to the JSON property tier
6604 6605 6606 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6604 def tier @tier end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6611 def update!(**args) @disk_quota = args[:disk_quota] if args.key?(:disk_quota) @ram = args[:ram] if args.key?(:ram) @kind = args[:kind] if args.key?(:kind) @region = args[:region] if args.key?(:region) @tier = args[:tier] if args.key?(:tier) end |