Class: Google::Apis::SqladminV1::Value
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::Value
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
The cell value of the table.
Instance Attribute Summary collapse
-
#null_value ⇒ Boolean
(also: #null_value?)
If cell value is null, then this flag will be set to true.
-
#value ⇒ String
The cell value in string format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Value
constructor
A new instance of Value.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Value
Returns a new instance of Value.
6700 6701 6702 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6700 def initialize(**args) update!(**args) end |
Instance Attribute Details
#null_value ⇒ Boolean Also known as: null_value?
If cell value is null, then this flag will be set to true.
Corresponds to the JSON property nullValue
6692 6693 6694 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6692 def null_value @null_value end |
#value ⇒ String
The cell value in string format.
Corresponds to the JSON property value
6698 6699 6700 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6698 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6705 6706 6707 6708 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6705 def update!(**args) @null_value = args[:null_value] if args.key?(:null_value) @value = args[:value] if args.key?(:value) end |