Class: Google::Apis::SqladminV1::ConnectSettings
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::ConnectSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Connect settings retrieval response.
Instance Attribute Summary collapse
-
#backend_type ⇒ String
SECOND_GEN: Cloud SQL database instance. -
#custom_subject_alternative_names ⇒ Array<String>
Custom subject alternative names for the server certificate.
-
#database_version ⇒ String
The database engine type and version.
-
#dns_name ⇒ String
The dns name of the instance.
-
#dns_names ⇒ Array<Google::Apis::SqladminV1::DnsNameMapping>
Output only.
-
#ip_addresses ⇒ Array<Google::Apis::SqladminV1::IpMapping>
The assigned IP addresses for the instance.
-
#kind ⇒ String
This is always
sql#connectSettings. -
#mdx_protocol_support ⇒ Array<String>
Optional.
-
#node_count ⇒ Fixnum
The number of read pool nodes in a read pool.
-
#nodes ⇒ Array<Google::Apis::SqladminV1::ConnectPoolNodeConfig>
Output only.
-
#psc_enabled ⇒ Boolean
(also: #psc_enabled?)
Whether PSC connectivity is enabled for this instance.
-
#region ⇒ String
The cloud region for the instance.
-
#server_ca_cert ⇒ Google::Apis::SqladminV1::SslCert
SslCerts Resource Corresponds to the JSON property
serverCaCert. -
#server_ca_mode ⇒ String
Specify what type of CA is used for the server certificate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConnectSettings
constructor
A new instance of ConnectSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConnectSettings
Returns a new instance of ConnectSettings.
980 981 982 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 980 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_type ⇒ String
SECOND_GEN: Cloud SQL database instance. EXTERNAL: A database server that
is not managed by Google. This property is read-only; use the tier property
in the settings object to determine the database type.
Corresponds to the JSON property backendType
899 900 901 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 899 def backend_type @backend_type end |
#custom_subject_alternative_names ⇒ Array<String>
Custom subject alternative names for the server certificate.
Corresponds to the JSON property customSubjectAlternativeNames
904 905 906 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 904 def custom_subject_alternative_names @custom_subject_alternative_names end |
#database_version ⇒ String
The database engine type and version. The databaseVersion field cannot be
changed after instance creation. MySQL instances: MYSQL_8_0, MYSQL_5_7 (
default), or MYSQL_5_6. PostgreSQL instances: POSTGRES_9_6, POSTGRES_10,
POSTGRES_11, POSTGRES_12 (default), POSTGRES_13, or POSTGRES_14. SQL
Server instances: SQLSERVER_2017_STANDARD (default),
SQLSERVER_2017_ENTERPRISE, SQLSERVER_2017_EXPRESS, SQLSERVER_2017_WEB,
SQLSERVER_2019_STANDARD, SQLSERVER_2019_ENTERPRISE, SQLSERVER_2019_EXPRESS
, or SQLSERVER_2019_WEB.
Corresponds to the JSON property databaseVersion
916 917 918 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 916 def database_version @database_version end |
#dns_name ⇒ String
The dns name of the instance.
Corresponds to the JSON property dnsName
921 922 923 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 921 def dns_name @dns_name end |
#dns_names ⇒ Array<Google::Apis::SqladminV1::DnsNameMapping>
Output only. The list of DNS names used by this instance.
Corresponds to the JSON property dnsNames
926 927 928 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 926 def dns_names @dns_names end |
#ip_addresses ⇒ Array<Google::Apis::SqladminV1::IpMapping>
The assigned IP addresses for the instance.
Corresponds to the JSON property ipAddresses
931 932 933 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 931 def ip_addresses @ip_addresses end |
#kind ⇒ String
This is always sql#connectSettings.
Corresponds to the JSON property kind
936 937 938 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 936 def kind @kind end |
#mdx_protocol_support ⇒ Array<String>
Optional. Output only. mdx_protocol_support controls how the client uses
metadata exchange when connecting to the instance. The values in the list
representing parts of the MDX protocol that are supported by this instance.
When the list is empty, the instance does not support MDX, so the client must
not send an MDX request. The default is empty.
Corresponds to the JSON property mdxProtocolSupport
945 946 947 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 945 def mdx_protocol_support @mdx_protocol_support end |
#node_count ⇒ Fixnum
The number of read pool nodes in a read pool.
Corresponds to the JSON property nodeCount
950 951 952 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 950 def node_count @node_count end |
#nodes ⇒ Array<Google::Apis::SqladminV1::ConnectPoolNodeConfig>
Output only. Entries containing information about each read pool node of the
read pool.
Corresponds to the JSON property nodes
956 957 958 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 956 def nodes @nodes end |
#psc_enabled ⇒ Boolean Also known as: psc_enabled?
Whether PSC connectivity is enabled for this instance.
Corresponds to the JSON property pscEnabled
961 962 963 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 961 def psc_enabled @psc_enabled end |
#region ⇒ String
The cloud region for the instance. For example, us-central1, europe-west1.
The region cannot be changed after instance creation.
Corresponds to the JSON property region
968 969 970 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 968 def region @region end |
#server_ca_cert ⇒ Google::Apis::SqladminV1::SslCert
SslCerts Resource
Corresponds to the JSON property serverCaCert
973 974 975 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 973 def server_ca_cert @server_ca_cert end |
#server_ca_mode ⇒ String
Specify what type of CA is used for the server certificate.
Corresponds to the JSON property serverCaMode
978 979 980 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 978 def server_ca_mode @server_ca_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 985 def update!(**args) @backend_type = args[:backend_type] if args.key?(:backend_type) @custom_subject_alternative_names = args[:custom_subject_alternative_names] if args.key?(:custom_subject_alternative_names) @database_version = args[:database_version] if args.key?(:database_version) @dns_name = args[:dns_name] if args.key?(:dns_name) @dns_names = args[:dns_names] if args.key?(:dns_names) @ip_addresses = args[:ip_addresses] if args.key?(:ip_addresses) @kind = args[:kind] if args.key?(:kind) @mdx_protocol_support = args[:mdx_protocol_support] if args.key?(:mdx_protocol_support) @node_count = args[:node_count] if args.key?(:node_count) @nodes = args[:nodes] if args.key?(:nodes) @psc_enabled = args[:psc_enabled] if args.key?(:psc_enabled) @region = args[:region] if args.key?(:region) @server_ca_cert = args[:server_ca_cert] if args.key?(:server_ca_cert) @server_ca_mode = args[:server_ca_mode] if args.key?(:server_ca_mode) end |