Class: Google::Apis::SqladminV1::DatabaseFlags

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Database flags for Cloud SQL instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseFlags

Returns a new instance of DatabaseFlags.



1169
1170
1171
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1169

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the flag. These flags are passed at instance startup, so include both server options and system variables. Flags are specified with underscores, not hyphens. For more information, see Configuring Database Flags in the Cloud SQL documentation. Corresponds to the JSON property name

Returns:

  • (String)


1161
1162
1163
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1161

def name
  @name
end

#valueString

The value of the flag. Boolean flags are set to on for true and off for false. This field must be omitted if the flag doesn't take a value. Corresponds to the JSON property value

Returns:

  • (String)


1167
1168
1169
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1167

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1174
1175
1176
1177
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1174

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end