Class: Google::Apis::SqladminV1::DatabaseInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

A Cloud SQL instance resource.

Defined Under Namespace

Classes: FailoverReplica

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseInstance

Returns a new instance of DatabaseInstance.



1480
1481
1482
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1480

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_maintenance_versionsArray<String>

Output only. List all maintenance versions applicable on the instance Corresponds to the JSON property availableMaintenanceVersions

Returns:

  • (Array<String>)


1187
1188
1189
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1187

def available_maintenance_versions
  @available_maintenance_versions
end

#backend_typeString

The backend type. SECOND_GEN: Cloud SQL database instance. EXTERNAL: A database server that is not managed by Google. This property is read-only; use the tier property in the settings object to determine the database type. Corresponds to the JSON property backendType

Returns:

  • (String)


1194
1195
1196
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1194

def backend_type
  @backend_type
end

#connection_nameString

Connection name of the Cloud SQL instance used in connection strings. Corresponds to the JSON property connectionName

Returns:

  • (String)


1199
1200
1201
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1199

def connection_name
  @connection_name
end

#create_timeString

Output only. The time when the instance was created in RFC 3339 format, for example 2012-11-15T16:19:00.094Z. Corresponds to the JSON property createTime

Returns:

  • (String)


1205
1206
1207
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1205

def create_time
  @create_time
end

#current_disk_sizeFixnum

The current disk usage of the instance in bytes. This property has been deprecated. Use the "cloudsql.googleapis.com/database/disk/bytes_used" metric in Cloud Monitoring API instead. Please see this announcement for details. Corresponds to the JSON property currentDiskSize

Returns:

  • (Fixnum)


1214
1215
1216
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1214

def current_disk_size
  @current_disk_size
end

#database_installed_versionString

Output only. Stores the current database version running on the instance including minor version such as MYSQL_8_0_18. Corresponds to the JSON property databaseInstalledVersion

Returns:

  • (String)


1220
1221
1222
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1220

def database_installed_version
  @database_installed_version
end

#database_versionString

The database engine type and version. The databaseVersion field cannot be changed after instance creation. Corresponds to the JSON property databaseVersion

Returns:

  • (String)


1226
1227
1228
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1226

def database_version
  @database_version
end

#disk_encryption_configurationGoogle::Apis::SqladminV1::DiskEncryptionConfiguration

Disk encryption configuration for an instance. Corresponds to the JSON property diskEncryptionConfiguration



1231
1232
1233
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1231

def disk_encryption_configuration
  @disk_encryption_configuration
end

#disk_encryption_statusGoogle::Apis::SqladminV1::DiskEncryptionStatus

Disk encryption status for an instance. Corresponds to the JSON property diskEncryptionStatus



1236
1237
1238
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1236

def disk_encryption_status
  @disk_encryption_status
end

#dns_nameString

Output only. The dns name of the instance. Corresponds to the JSON property dnsName

Returns:

  • (String)


1241
1242
1243
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1241

def dns_name
  @dns_name
end

#dns_namesArray<Google::Apis::SqladminV1::DnsNameMapping>

Output only. The list of DNS names used by this instance. Corresponds to the JSON property dnsNames



1246
1247
1248
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1246

def dns_names
  @dns_names
end

#etagString

This field is deprecated and will be removed from a future version of the API. Use the settings.settingsVersion field instead. Corresponds to the JSON property etag

Returns:

  • (String)


1252
1253
1254
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1252

def etag
  @etag
end

#failover_replicaGoogle::Apis::SqladminV1::DatabaseInstance::FailoverReplica

The name and status of the failover replica. Corresponds to the JSON property failoverReplica



1257
1258
1259
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1257

def failover_replica
  @failover_replica
end

#gce_zoneString

The Compute Engine zone that the instance is currently serving from. This value could be different from the zone that was specified when the instance was created if the instance has failed over to its secondary zone. WARNING: Changing this might restart the instance. Corresponds to the JSON property gceZone

Returns:

  • (String)


1265
1266
1267
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1265

def gce_zone
  @gce_zone
end

#gemini_configGoogle::Apis::SqladminV1::GeminiInstanceConfig

Gemini instance configuration. Corresponds to the JSON property geminiConfig



1270
1271
1272
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1270

def gemini_config
  @gemini_config
end

#include_replicas_for_major_version_upgradeBoolean Also known as: include_replicas_for_major_version_upgrade?

Input only. Determines whether an in-place major version upgrade of replicas happens when an in-place major version upgrade of a primary instance is initiated. Corresponds to the JSON property includeReplicasForMajorVersionUpgrade

Returns:

  • (Boolean)


1277
1278
1279
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1277

def include_replicas_for_major_version_upgrade
  @include_replicas_for_major_version_upgrade
end

#instance_typeString

The instance type. Corresponds to the JSON property instanceType

Returns:

  • (String)


1283
1284
1285
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1283

def instance_type
  @instance_type
end

#ip_addressesArray<Google::Apis::SqladminV1::IpMapping>

The assigned IP addresses for the instance. Corresponds to the JSON property ipAddresses



1288
1289
1290
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1288

def ip_addresses
  @ip_addresses
end

#ipv6_addressString

The IPv6 address assigned to the instance. (Deprecated) This property was applicable only to First Generation instances. Corresponds to the JSON property ipv6Address

Returns:

  • (String)


1294
1295
1296
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1294

def ipv6_address
  @ipv6_address
end

#kindString

This is always sql#instance. Corresponds to the JSON property kind

Returns:

  • (String)


1299
1300
1301
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1299

def kind
  @kind
end

#maintenance_versionString

The current software version on the instance. Corresponds to the JSON property maintenanceVersion

Returns:

  • (String)


1304
1305
1306
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1304

def maintenance_version
  @maintenance_version
end

#master_instance_nameString

The name of the instance which will act as primary in the replication setup. Corresponds to the JSON property masterInstanceName

Returns:

  • (String)


1309
1310
1311
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1309

def master_instance_name
  @master_instance_name
end

#max_disk_sizeFixnum

The maximum disk size of the instance in bytes. Corresponds to the JSON property maxDiskSize

Returns:

  • (Fixnum)


1314
1315
1316
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1314

def max_disk_size
  @max_disk_size
end

#nameString

Name of the Cloud SQL instance. This does not include the project ID. Corresponds to the JSON property name

Returns:

  • (String)


1319
1320
1321
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1319

def name
  @name
end

#node_countFixnum

The number of read pool nodes in a read pool. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


1324
1325
1326
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1324

def node_count
  @node_count
end

#nodesArray<Google::Apis::SqladminV1::PoolNodeConfig>

Output only. Entries containing information about each read pool node of the read pool. Corresponds to the JSON property nodes



1330
1331
1332
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1330

def nodes
  @nodes
end

#on_premises_configurationGoogle::Apis::SqladminV1::OnPremisesConfiguration

On-premises instance configuration. Corresponds to the JSON property onPremisesConfiguration



1335
1336
1337
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1335

def on_premises_configuration
  @on_premises_configuration
end

#out_of_disk_reportGoogle::Apis::SqladminV1::SqlOutOfDiskReport

This message wraps up the information written by out-of-disk detection job. Corresponds to the JSON property outOfDiskReport



1340
1341
1342
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1340

def out_of_disk_report
  @out_of_disk_report
end

#primary_dns_nameString

Output only. DEPRECATED: please use write_endpoint instead. Corresponds to the JSON property primaryDnsName

Returns:

  • (String)


1345
1346
1347
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1345

def primary_dns_name
  @primary_dns_name
end

#projectString

The project ID of the project containing the Cloud SQL instance. The Google apps domain is prefixed if applicable. Corresponds to the JSON property project

Returns:

  • (String)


1351
1352
1353
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1351

def project
  @project
end

Output only. The link to service attachment of PSC instance. Corresponds to the JSON property pscServiceAttachmentLink

Returns:

  • (String)


1356
1357
1358
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1356

def psc_service_attachment_link
  @psc_service_attachment_link
end

#regionString

The geographical region of the Cloud SQL instance. It can be one of the regions where Cloud SQL operates: For example, asia-east1, europe-west1, and us- central1. The default value is us-central1. Corresponds to the JSON property region

Returns:

  • (String)


1364
1365
1366
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1364

def region
  @region
end

#replica_configurationGoogle::Apis::SqladminV1::ReplicaConfiguration

Read-replica configuration for connecting to the primary instance. Corresponds to the JSON property replicaConfiguration



1369
1370
1371
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1369

def replica_configuration
  @replica_configuration
end

#replica_namesArray<String>

The replicas of the instance. Corresponds to the JSON property replicaNames

Returns:

  • (Array<String>)


1374
1375
1376
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1374

def replica_names
  @replica_names
end

#replication_clusterGoogle::Apis::SqladminV1::ReplicationCluster

A primary instance and disaster recovery (DR) replica pair. A DR replica is a cross-region replica that you designate for failover in the event that the primary instance experiences regional failure. Applicable to MySQL and PostgreSQL. Corresponds to the JSON property replicationCluster



1382
1383
1384
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1382

def replication_cluster
  @replication_cluster
end

#root_passwordString

Initial root password. Use only on creation. You must set root passwords before you can connect to PostgreSQL instances. Corresponds to the JSON property rootPassword

Returns:

  • (String)


1388
1389
1390
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1388

def root_password
  @root_password
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. This status indicates whether the instance satisfies PZI. The status is reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


1394
1395
1396
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1394

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

This status indicates whether the instance satisfies PZS. The status is reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


1401
1402
1403
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1401

def satisfies_pzs
  @satisfies_pzs
end

#scheduled_maintenanceGoogle::Apis::SqladminV1::SqlScheduledMaintenance

Any scheduled maintenance for this instance. Corresponds to the JSON property scheduledMaintenance



1407
1408
1409
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1407

def scheduled_maintenance
  @scheduled_maintenance
end

#secondary_gce_zoneString

The Compute Engine zone that the failover instance is currently serving from for a regional instance. This value could be different from the zone that was specified when the instance was created if the instance has failed over to its secondary/failover zone. Corresponds to the JSON property secondaryGceZone

Returns:

  • (String)


1415
1416
1417
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1415

def secondary_gce_zone
  @secondary_gce_zone
end

The URI of this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


1420
1421
1422
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1420

def self_link
  @self_link
end

#server_ca_certGoogle::Apis::SqladminV1::SslCert

SslCerts Resource Corresponds to the JSON property serverCaCert



1425
1426
1427
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1425

def server_ca_cert
  @server_ca_cert
end

#service_account_email_addressString

The service account email address assigned to the instance.\This property is read-only. Corresponds to the JSON property serviceAccountEmailAddress

Returns:

  • (String)


1431
1432
1433
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1431

def 
  @service_account_email_address
end

#settingsGoogle::Apis::SqladminV1::Settings

Database instance settings. Corresponds to the JSON property settings



1436
1437
1438
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1436

def settings
  @settings
end

#sql_network_architectureString

Corresponds to the JSON property sqlNetworkArchitecture

Returns:

  • (String)


1441
1442
1443
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1441

def sql_network_architecture
  @sql_network_architecture
end

#stateString

The current serving state of the Cloud SQL instance. Corresponds to the JSON property state

Returns:

  • (String)


1446
1447
1448
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1446

def state
  @state
end

#suspension_reasonArray<String>

If the instance state is SUSPENDED, the reason for the suspension. Corresponds to the JSON property suspensionReason

Returns:

  • (Array<String>)


1451
1452
1453
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1451

def suspension_reason
  @suspension_reason
end

#switch_transaction_logs_to_cloud_storage_enabledBoolean Also known as: switch_transaction_logs_to_cloud_storage_enabled?

Input only. Whether Cloud SQL is enabled to switch storing point-in-time recovery log files from a data disk to Cloud Storage. Corresponds to the JSON property switchTransactionLogsToCloudStorageEnabled

Returns:

  • (Boolean)


1457
1458
1459
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1457

def switch_transaction_logs_to_cloud_storage_enabled
  @switch_transaction_logs_to_cloud_storage_enabled
end

#tagsHash<String,String>

Optional. Input only. Immutable. Tag keys and tag values that are bound to this instance. You must represent each item in the map as: "" : "". For example, a single resource can have the following tags: "123/environment": "production", "123/costCenter": "marketing", For more information on tag creation and management, see https://cloud.google.com/resource-manager/docs/ tags/tags-overview. Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


1468
1469
1470
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1468

def tags
  @tags
end

#upgradable_database_versionsArray<Google::Apis::SqladminV1::AvailableDatabaseVersion>

Output only. All database versions that are available for upgrade. Corresponds to the JSON property upgradableDatabaseVersions



1473
1474
1475
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1473

def upgradable_database_versions
  @upgradable_database_versions
end

#write_endpointString

Output only. The dns name of the primary instance in a replication group. Corresponds to the JSON property writeEndpoint

Returns:

  • (String)


1478
1479
1480
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1478

def write_endpoint
  @write_endpoint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1485

def update!(**args)
  @available_maintenance_versions = args[:available_maintenance_versions] if args.key?(:available_maintenance_versions)
  @backend_type = args[:backend_type] if args.key?(:backend_type)
  @connection_name = args[:connection_name] if args.key?(:connection_name)
  @create_time = args[:create_time] if args.key?(:create_time)
  @current_disk_size = args[:current_disk_size] if args.key?(:current_disk_size)
  @database_installed_version = args[:database_installed_version] if args.key?(:database_installed_version)
  @database_version = args[:database_version] if args.key?(:database_version)
  @disk_encryption_configuration = args[:disk_encryption_configuration] if args.key?(:disk_encryption_configuration)
  @disk_encryption_status = args[:disk_encryption_status] if args.key?(:disk_encryption_status)
  @dns_name = args[:dns_name] if args.key?(:dns_name)
  @dns_names = args[:dns_names] if args.key?(:dns_names)
  @etag = args[:etag] if args.key?(:etag)
  @failover_replica = args[:failover_replica] if args.key?(:failover_replica)
  @gce_zone = args[:gce_zone] if args.key?(:gce_zone)
  @gemini_config = args[:gemini_config] if args.key?(:gemini_config)
  @include_replicas_for_major_version_upgrade = args[:include_replicas_for_major_version_upgrade] if args.key?(:include_replicas_for_major_version_upgrade)
  @instance_type = args[:instance_type] if args.key?(:instance_type)
  @ip_addresses = args[:ip_addresses] if args.key?(:ip_addresses)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @kind = args[:kind] if args.key?(:kind)
  @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version)
  @master_instance_name = args[:master_instance_name] if args.key?(:master_instance_name)
  @max_disk_size = args[:max_disk_size] if args.key?(:max_disk_size)
  @name = args[:name] if args.key?(:name)
  @node_count = args[:node_count] if args.key?(:node_count)
  @nodes = args[:nodes] if args.key?(:nodes)
  @on_premises_configuration = args[:on_premises_configuration] if args.key?(:on_premises_configuration)
  @out_of_disk_report = args[:out_of_disk_report] if args.key?(:out_of_disk_report)
  @primary_dns_name = args[:primary_dns_name] if args.key?(:primary_dns_name)
  @project = args[:project] if args.key?(:project)
  @psc_service_attachment_link = args[:psc_service_attachment_link] if args.key?(:psc_service_attachment_link)
  @region = args[:region] if args.key?(:region)
  @replica_configuration = args[:replica_configuration] if args.key?(:replica_configuration)
  @replica_names = args[:replica_names] if args.key?(:replica_names)
  @replication_cluster = args[:replication_cluster] if args.key?(:replication_cluster)
  @root_password = args[:root_password] if args.key?(:root_password)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scheduled_maintenance = args[:scheduled_maintenance] if args.key?(:scheduled_maintenance)
  @secondary_gce_zone = args[:secondary_gce_zone] if args.key?(:secondary_gce_zone)
  @self_link = args[:self_link] if args.key?(:self_link)
  @server_ca_cert = args[:server_ca_cert] if args.key?(:server_ca_cert)
  @service_account_email_address = args[:service_account_email_address] if args.key?(:service_account_email_address)
  @settings = args[:settings] if args.key?(:settings)
  @sql_network_architecture = args[:sql_network_architecture] if args.key?(:sql_network_architecture)
  @state = args[:state] if args.key?(:state)
  @suspension_reason = args[:suspension_reason] if args.key?(:suspension_reason)
  @switch_transaction_logs_to_cloud_storage_enabled = args[:switch_transaction_logs_to_cloud_storage_enabled] if args.key?(:switch_transaction_logs_to_cloud_storage_enabled)
  @tags = args[:tags] if args.key?(:tags)
  @upgradable_database_versions = args[:upgradable_database_versions] if args.key?(:upgradable_database_versions)
  @write_endpoint = args[:write_endpoint] if args.key?(:write_endpoint)
end