Class: Google::Apis::SqladminV1::ExecuteSqlPayload
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::ExecuteSqlPayload
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
The request payload used to execute SQL statements.
Instance Attribute Summary collapse
-
#application ⇒ String
Optional.
-
#auto_iam_authn ⇒ Boolean
(also: #auto_iam_authn?)
Optional.
-
#database ⇒ String
Optional.
-
#partial_result_mode ⇒ String
Optional.
-
#row_limit ⇒ Fixnum
Optional.
-
#sql_statement ⇒ String
Required.
-
#user ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExecuteSqlPayload
constructor
A new instance of ExecuteSqlPayload.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExecuteSqlPayload
Returns a new instance of ExecuteSqlPayload.
1949 1950 1951 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1949 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application ⇒ String
Optional. Specifies the name of the application that is making the request.
This field is used for telemetry. Only alphanumeric characters, dashes, and
underscores are allowed. The maximum length is 32 characters.
Corresponds to the JSON property application
1909 1910 1911 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1909 def application @application end |
#auto_iam_authn ⇒ Boolean Also known as: auto_iam_authn?
Optional. When set to true, the API caller identity associated with the
request is used for database authentication. The API caller must be an IAM
user in the database.
Corresponds to the JSON property autoIamAuthn
1916 1917 1918 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1916 def auto_iam_authn @auto_iam_authn end |
#database ⇒ String
Optional. Name of the database on which the statement will be executed.
Corresponds to the JSON property database
1922 1923 1924 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1922 def database @database end |
#partial_result_mode ⇒ String
Optional. Controls how the API should respond when the SQL execution result is
incomplete due to the size limit or another error. The default mode is to
throw an error.
Corresponds to the JSON property partialResultMode
1929 1930 1931 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1929 def partial_result_mode @partial_result_mode end |
#row_limit ⇒ Fixnum
Optional. The maximum number of rows returned per SQL statement.
Corresponds to the JSON property rowLimit
1934 1935 1936 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1934 def row_limit @row_limit end |
#sql_statement ⇒ String
Required. SQL statements to run on the database. It can be a single statement
or a sequence of statements separated by semicolons.
Corresponds to the JSON property sqlStatement
1940 1941 1942 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1940 def sql_statement @sql_statement end |
#user ⇒ String
Optional. The name of an existing database user to connect to the database.
When auto_iam_authn is set to true, this field is ignored and the API caller'
s IAM user is used.
Corresponds to the JSON property user
1947 1948 1949 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1947 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1954 1955 1956 1957 1958 1959 1960 1961 1962 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 1954 def update!(**args) @application = args[:application] if args.key?(:application) @auto_iam_authn = args[:auto_iam_authn] if args.key?(:auto_iam_authn) @database = args[:database] if args.key?(:database) @partial_result_mode = args[:partial_result_mode] if args.key?(:partial_result_mode) @row_limit = args[:row_limit] if args.key?(:row_limit) @sql_statement = args[:sql_statement] if args.key?(:sql_statement) @user = args[:user] if args.key?(:user) end |