Class: Google::Apis::SqladminV1::ExportContext::BakExportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Options for exporting BAK files (SQL Server-only)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BakExportOptions

Returns a new instance of BakExportOptions.



2089
2090
2091
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2089

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bak_typeString

Type of this bak file will be export, FULL or DIFF, SQL Server only Corresponds to the JSON property bakType

Returns:

  • (String)


2044
2045
2046
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2044

def bak_type
  @bak_type
end

#copy_onlyBoolean Also known as: copy_only?

Deprecated: copy_only is deprecated. Use differential_base instead Corresponds to the JSON property copyOnly

Returns:

  • (Boolean)


2049
2050
2051
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2049

def copy_only
  @copy_only
end

#differential_baseBoolean Also known as: differential_base?

Whether or not the backup can be used as a differential base copy_only backup can not be served as differential base Corresponds to the JSON property differentialBase

Returns:

  • (Boolean)


2056
2057
2058
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2056

def differential_base
  @differential_base
end

#export_log_end_timeString

Optional. The end timestamp when transaction log will be included in the export operation. RFC 3339 format (for example, 2023-10-01T16:19:00.094) in UTC. When omitted, all available logs until current time will be included. Only applied to Cloud SQL for SQL Server. Corresponds to the JSON property exportLogEndTime

Returns:

  • (String)


2065
2066
2067
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2065

def export_log_end_time
  @export_log_end_time
end

#export_log_start_timeString

Optional. The begin timestamp when transaction log will be included in the export operation. RFC 3339 format (for example, 2023-10-01T16:19:00.094) in UTC. When omitted, all available logs from the beginning of retention period will be included. Only applied to Cloud SQL for SQL Server. Corresponds to the JSON property exportLogStartTime

Returns:

  • (String)


2074
2075
2076
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2074

def export_log_start_time
  @export_log_start_time
end

#stripe_countFixnum

Option for specifying how many stripes to use for the export. If blank, and the value of the striped field is true, the number of stripes is automatically chosen. Corresponds to the JSON property stripeCount

Returns:

  • (Fixnum)


2081
2082
2083
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2081

def stripe_count
  @stripe_count
end

#stripedBoolean Also known as: striped?

Whether or not the export should be striped. Corresponds to the JSON property striped

Returns:

  • (Boolean)


2086
2087
2088
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2086

def striped
  @striped
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2094
2095
2096
2097
2098
2099
2100
2101
2102
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2094

def update!(**args)
  @bak_type = args[:bak_type] if args.key?(:bak_type)
  @copy_only = args[:copy_only] if args.key?(:copy_only)
  @differential_base = args[:differential_base] if args.key?(:differential_base)
  @export_log_end_time = args[:export_log_end_time] if args.key?(:export_log_end_time)
  @export_log_start_time = args[:export_log_start_time] if args.key?(:export_log_start_time)
  @stripe_count = args[:stripe_count] if args.key?(:stripe_count)
  @striped = args[:striped] if args.key?(:striped)
end