Class: Google::Apis::SqladminV1::ExportContext::SqlExportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Options for exporting data as SQL statements.

Defined Under Namespace

Classes: MysqlExportOptions, PostgresExportOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlExportOptions

Returns a new instance of SqlExportOptions.



2189
2190
2191
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2189

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mysql_export_optionsGoogle::Apis::SqladminV1::ExportContext::SqlExportOptions::MysqlExportOptions

Options for exporting from MySQL. Corresponds to the JSON property mysqlExportOptions



2158
2159
2160
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2158

def mysql_export_options
  @mysql_export_options
end

#parallelBoolean Also known as: parallel?

Optional. Whether or not the export should be parallel. Corresponds to the JSON property parallel

Returns:

  • (Boolean)


2163
2164
2165
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2163

def parallel
  @parallel
end

#postgres_export_optionsGoogle::Apis::SqladminV1::ExportContext::SqlExportOptions::PostgresExportOptions

Options for exporting from a Cloud SQL for PostgreSQL instance. Corresponds to the JSON property postgresExportOptions



2169
2170
2171
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2169

def postgres_export_options
  @postgres_export_options
end

#schema_onlyBoolean Also known as: schema_only?

Export only schemas. Corresponds to the JSON property schemaOnly

Returns:

  • (Boolean)


2174
2175
2176
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2174

def schema_only
  @schema_only
end

#tablesArray<String>

Tables to export, or that were exported, from the specified database. If you specify tables, specify one and only one database. For PostgreSQL instances, you can specify only one table. Corresponds to the JSON property tables

Returns:

  • (Array<String>)


2182
2183
2184
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2182

def tables
  @tables
end

#threadsFixnum

Optional. The number of threads to use for parallel export. Corresponds to the JSON property threads

Returns:

  • (Fixnum)


2187
2188
2189
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2187

def threads
  @threads
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2194
2195
2196
2197
2198
2199
2200
2201
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2194

def update!(**args)
  @mysql_export_options = args[:mysql_export_options] if args.key?(:mysql_export_options)
  @parallel = args[:parallel] if args.key?(:parallel)
  @postgres_export_options = args[:postgres_export_options] if args.key?(:postgres_export_options)
  @schema_only = args[:schema_only] if args.key?(:schema_only)
  @tables = args[:tables] if args.key?(:tables)
  @threads = args[:threads] if args.key?(:threads)
end