Class: Google::Apis::SqladminV1::ExportContext::TdeExportOptions
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::ExportContext::TdeExportOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Optional. Export parameters specific to SQL Server TDE certificates
Instance Attribute Summary collapse
-
#certificate_path ⇒ String
Required.
-
#name ⇒ String
Required.
-
#private_key_password ⇒ String
Required.
-
#private_key_path ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TdeExportOptions
constructor
A new instance of TdeExportOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TdeExportOptions
Returns a new instance of TdeExportOptions.
2284 2285 2286 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2284 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_path ⇒ String
Required. Path to the TDE certificate public key in the form gs://bucketName/
fileName. The instance must have write access to the bucket. Applicable only
for SQL Server instances.
Corresponds to the JSON property certificatePath
2265 2266 2267 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2265 def certificate_path @certificate_path end |
#name ⇒ String
Required. Certificate name. Applicable only for SQL Server instances.
Corresponds to the JSON property name
2270 2271 2272 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2270 def name @name end |
#private_key_password ⇒ String
Required. Password that encrypts the private key.
Corresponds to the JSON property privateKeyPassword
2275 2276 2277 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2275 def private_key_password @private_key_password end |
#private_key_path ⇒ String
Required. Path to the TDE certificate private key in the form gs://bucketName/
fileName. The instance must have write access to the location. Applicable only
for SQL Server instances.
Corresponds to the JSON property privateKeyPath
2282 2283 2284 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2282 def private_key_path @private_key_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2289 2290 2291 2292 2293 2294 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2289 def update!(**args) @certificate_path = args[:certificate_path] if args.key?(:certificate_path) @name = args[:name] if args.key?(:name) @private_key_password = args[:private_key_password] if args.key?(:private_key_password) @private_key_path = args[:private_key_path] if args.key?(:private_key_path) end |