Class: Google::Apis::SqladminV1::ImportContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Database instance import context.

Defined Under Namespace

Classes: BakImportOptions, CsvImportOptions, SqlImportOptions, TdeImportOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportContext

Returns a new instance of ImportContext.



2677
2678
2679
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2677

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bak_import_optionsGoogle::Apis::SqladminV1::ImportContext::BakImportOptions

Import parameters specific to SQL Server .BAK files Corresponds to the JSON property bakImportOptions



2626
2627
2628
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2626

def bak_import_options
  @bak_import_options
end

#csv_import_optionsGoogle::Apis::SqladminV1::ImportContext::CsvImportOptions

Options for importing data as CSV. Corresponds to the JSON property csvImportOptions



2631
2632
2633
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2631

def csv_import_options
  @csv_import_options
end

#databaseString

The target database for the import. If fileType is SQL, this field is required only if the import file does not specify a database, and is overridden by any database specification in the import file. For entire instance parallel import operations, the database is overridden by the database name stored in subdirectory name. If fileType is CSV, one database must be specified. Corresponds to the JSON property database

Returns:

  • (String)


2641
2642
2643
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2641

def database
  @database
end

#file_typeString

The file type for the specified uri.`SQL: The file contains SQL statements. \ CSV: The file contains CSV data. Corresponds to the JSON propertyfileType`

Returns:

  • (String)


2647
2648
2649
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2647

def file_type
  @file_type
end

#import_userString

The PostgreSQL user for this import operation. PostgreSQL instances only. Corresponds to the JSON property importUser

Returns:

  • (String)


2652
2653
2654
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2652

def import_user
  @import_user
end

#kindString

This is always sql#importContext. Corresponds to the JSON property kind

Returns:

  • (String)


2657
2658
2659
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2657

def kind
  @kind
end

#sql_import_optionsGoogle::Apis::SqladminV1::ImportContext::SqlImportOptions

Optional. Options for importing data from SQL statements. Corresponds to the JSON property sqlImportOptions



2662
2663
2664
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2662

def sql_import_options
  @sql_import_options
end

#tde_import_optionsGoogle::Apis::SqladminV1::ImportContext::TdeImportOptions

Optional. Import parameters specific to SQL Server TDE certificates Corresponds to the JSON property tdeImportOptions



2667
2668
2669
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2667

def tde_import_options
  @tde_import_options
end

#uriString

Path to the import file in Cloud Storage, in the form gs://bucketName/ fileName. Compressed gzip files (.gz) are supported when fileType is SQL. The instance must have write permissions to the bucket and read access to the file. Corresponds to the JSON property uri

Returns:

  • (String)


2675
2676
2677
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2675

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2682

def update!(**args)
  @bak_import_options = args[:bak_import_options] if args.key?(:bak_import_options)
  @csv_import_options = args[:csv_import_options] if args.key?(:csv_import_options)
  @database = args[:database] if args.key?(:database)
  @file_type = args[:file_type] if args.key?(:file_type)
  @import_user = args[:import_user] if args.key?(:import_user)
  @kind = args[:kind] if args.key?(:kind)
  @sql_import_options = args[:sql_import_options] if args.key?(:sql_import_options)
  @tde_import_options = args[:tde_import_options] if args.key?(:tde_import_options)
  @uri = args[:uri] if args.key?(:uri)
end