Class: Google::Apis::SqladminV1::ImportContext::TdeImportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Optional. Import parameters specific to SQL Server TDE certificates

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TdeImportOptions

Returns a new instance of TdeImportOptions.



2937
2938
2939
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2937

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_pathString

Required. Path to the TDE certificate public key in the form gs://bucketName/ fileName. The instance must have read access to the file. Applicable only for SQL Server instances. Corresponds to the JSON property certificatePath

Returns:

  • (String)


2918
2919
2920
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2918

def certificate_path
  @certificate_path
end

#nameString

Required. Certificate name. Applicable only for SQL Server instances. Corresponds to the JSON property name

Returns:

  • (String)


2923
2924
2925
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2923

def name
  @name
end

#private_key_passwordString

Required. Password that encrypts the private key. Corresponds to the JSON property privateKeyPassword

Returns:

  • (String)


2928
2929
2930
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2928

def private_key_password
  @private_key_password
end

#private_key_pathString

Required. Path to the TDE certificate private key in the form gs://bucketName/ fileName. The instance must have read access to the file. Applicable only for SQL Server instances. Corresponds to the JSON property privateKeyPath

Returns:

  • (String)


2935
2936
2937
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2935

def private_key_path
  @private_key_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2942
2943
2944
2945
2946
2947
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2942

def update!(**args)
  @certificate_path = args[:certificate_path] if args.key?(:certificate_path)
  @name = args[:name] if args.key?(:name)
  @private_key_password = args[:private_key_password] if args.key?(:private_key_password)
  @private_key_path = args[:private_key_path] if args.key?(:private_key_path)
end