Class: Google::Apis::SqladminV1::InsightsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Insights configuration. This specifies when Cloud SQL Insights feature is enabled and optional configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsightsConfig

Returns a new instance of InsightsConfig.



3003
3004
3005
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3003

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enhanced_query_insights_enabledBoolean Also known as: enhanced_query_insights_enabled?

Optional. Whether enhanced query insights feature is enabled. Corresponds to the JSON property enhancedQueryInsightsEnabled

Returns:

  • (Boolean)


2968
2969
2970
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2968

def enhanced_query_insights_enabled
  @enhanced_query_insights_enabled
end

#query_insights_enabledBoolean Also known as: query_insights_enabled?

Whether Query Insights feature is enabled. Corresponds to the JSON property queryInsightsEnabled

Returns:

  • (Boolean)


2974
2975
2976
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2974

def query_insights_enabled
  @query_insights_enabled
end

#query_plans_per_minuteFixnum

Number of query execution plans captured by Insights per minute for all queries combined. Default is 5. Corresponds to the JSON property queryPlansPerMinute

Returns:

  • (Fixnum)


2981
2982
2983
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2981

def query_plans_per_minute
  @query_plans_per_minute
end

#query_string_lengthFixnum

Maximum query length stored in bytes. Default value: 1024 bytes. Range: 256- 4500 bytes. Query lengths greater than this field value will be truncated to this value. When unset, query length will be the default value. Changing query length will restart the database. Corresponds to the JSON property queryStringLength

Returns:

  • (Fixnum)


2989
2990
2991
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2989

def query_string_length
  @query_string_length
end

#record_application_tagsBoolean Also known as: record_application_tags?

Whether Query Insights will record application tags from query when enabled. Corresponds to the JSON property recordApplicationTags

Returns:

  • (Boolean)


2994
2995
2996
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 2994

def record_application_tags
  @record_application_tags
end

#record_client_addressBoolean Also known as: record_client_address?

Whether Query Insights will record client address when enabled. Corresponds to the JSON property recordClientAddress

Returns:

  • (Boolean)


3000
3001
3002
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3000

def record_client_address
  @record_client_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3008
3009
3010
3011
3012
3013
3014
3015
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3008

def update!(**args)
  @enhanced_query_insights_enabled = args[:enhanced_query_insights_enabled] if args.key?(:enhanced_query_insights_enabled)
  @query_insights_enabled = args[:query_insights_enabled] if args.key?(:query_insights_enabled)
  @query_plans_per_minute = args[:query_plans_per_minute] if args.key?(:query_plans_per_minute)
  @query_string_length = args[:query_string_length] if args.key?(:query_string_length)
  @record_application_tags = args[:record_application_tags] if args.key?(:record_application_tags)
  @record_client_address = args[:record_client_address] if args.key?(:record_client_address)
end