Class: Google::Apis::SqladminV1::InstancesRestoreBackupRequest
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::InstancesRestoreBackupRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Database instance restore backup request.
Instance Attribute Summary collapse
-
#backup ⇒ String
The name of the backup that's used to restore a Cloud SQL instance: Format: projects/
project-id/backups/backup-uid. -
#backupdr_backup ⇒ String
The name of the backup that's used to restore a Cloud SQL instance: Format: " projects/
project-id/locations/location/backupVaults/backupvault/ dataSources/datasource/backups/backup-uid". -
#restore_backup_context ⇒ Google::Apis::SqladminV1::RestoreBackupContext
Database instance restore from backup context.
-
#restore_instance_clear_overrides_field_names ⇒ Array<String>
Optional.
-
#restore_instance_settings ⇒ Google::Apis::SqladminV1::DatabaseInstance
A Cloud SQL instance resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstancesRestoreBackupRequest
constructor
A new instance of InstancesRestoreBackupRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstancesRestoreBackupRequest
Returns a new instance of InstancesRestoreBackupRequest.
3411 3412 3413 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3411 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup ⇒ String
The name of the backup that's used to restore a Cloud SQL instance: Format:
projects/project-id/backups/backup-uid. Only one of restore_backup_context,
backup, backupdr_backup can be passed to the input.
Corresponds to the JSON property backup
3383 3384 3385 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3383 def backup @backup end |
#backupdr_backup ⇒ String
The name of the backup that's used to restore a Cloud SQL instance: Format: "
projects/project-id/locations/location/backupVaults/backupvault/
dataSources/datasource/backups/backup-uid". Only one of
restore_backup_context, backup, backupdr_backup can be passed to the input.
Corresponds to the JSON property backupdrBackup
3391 3392 3393 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3391 def backupdr_backup @backupdr_backup end |
#restore_backup_context ⇒ Google::Apis::SqladminV1::RestoreBackupContext
Database instance restore from backup context. Backup context contains source
instance id and project id.
Corresponds to the JSON property restoreBackupContext
3397 3398 3399 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3397 def restore_backup_context @restore_backup_context end |
#restore_instance_clear_overrides_field_names ⇒ Array<String>
Optional. This field has the same purpose as restore_instance_settings,
changes any instance settings stored in the backup you are restoring from.
With the difference that these fields are cleared in the settings.
Corresponds to the JSON property restoreInstanceClearOverridesFieldNames
3404 3405 3406 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3404 def restore_instance_clear_overrides_field_names @restore_instance_clear_overrides_field_names end |
#restore_instance_settings ⇒ Google::Apis::SqladminV1::DatabaseInstance
A Cloud SQL instance resource.
Corresponds to the JSON property restoreInstanceSettings
3409 3410 3411 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3409 def restore_instance_settings @restore_instance_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3416 3417 3418 3419 3420 3421 3422 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3416 def update!(**args) @backup = args[:backup] if args.key?(:backup) @backupdr_backup = args[:backupdr_backup] if args.key?(:backupdr_backup) @restore_backup_context = args[:restore_backup_context] if args.key?(:restore_backup_context) @restore_instance_clear_overrides_field_names = args[:restore_instance_clear_overrides_field_names] if args.key?(:restore_instance_clear_overrides_field_names) @restore_instance_settings = args[:restore_instance_settings] if args.key?(:restore_instance_settings) end |