Class: Google::Apis::SqladminV1::InstancesRestoreBackupRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Database instance restore backup request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstancesRestoreBackupRequest

Returns a new instance of InstancesRestoreBackupRequest.



3399
3400
3401
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

The name of the backup that's used to restore a Cloud SQL instance: Format: projects/project-id/backups/backup-uid. Only one of restore_backup_context, backup, backupdr_backup can be passed to the input. Corresponds to the JSON property backup

Returns:

  • (String)


3371
3372
3373
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3371

def backup
  @backup
end

#backupdr_backupString

The name of the backup that's used to restore a Cloud SQL instance: Format: " projects/project-id/locations/location/backupVaults/backupvault/ dataSources/datasource/backups/backup-uid". Only one of restore_backup_context, backup, backupdr_backup can be passed to the input. Corresponds to the JSON property backupdrBackup

Returns:

  • (String)


3379
3380
3381
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3379

def backupdr_backup
  @backupdr_backup
end

#restore_backup_contextGoogle::Apis::SqladminV1::RestoreBackupContext

Database instance restore from backup context. Backup context contains source instance id and project id. Corresponds to the JSON property restoreBackupContext



3385
3386
3387
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3385

def restore_backup_context
  @restore_backup_context
end

#restore_instance_clear_overrides_field_namesArray<String>

Optional. This field has the same purpose as restore_instance_settings, changes any instance settings stored in the backup you are restoring from. With the difference that these fields are cleared in the settings. Corresponds to the JSON property restoreInstanceClearOverridesFieldNames

Returns:

  • (Array<String>)


3392
3393
3394
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3392

def restore_instance_clear_overrides_field_names
  @restore_instance_clear_overrides_field_names
end

#restore_instance_settingsGoogle::Apis::SqladminV1::DatabaseInstance

A Cloud SQL instance resource. Corresponds to the JSON property restoreInstanceSettings



3397
3398
3399
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3397

def restore_instance_settings
  @restore_instance_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3404
3405
3406
3407
3408
3409
3410
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3404

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @backupdr_backup = args[:backupdr_backup] if args.key?(:backupdr_backup)
  @restore_backup_context = args[:restore_backup_context] if args.key?(:restore_backup_context)
  @restore_instance_clear_overrides_field_names = args[:restore_instance_clear_overrides_field_names] if args.key?(:restore_instance_clear_overrides_field_names)
  @restore_instance_settings = args[:restore_instance_settings] if args.key?(:restore_instance_settings)
end