Class: Google::Apis::SqladminV1::ListBackupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

The response payload containing a list of the backups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupsResponse

Returns a new instance of ListBackupsResponse.



3699
3700
3701
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3699

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupsArray<Google::Apis::SqladminV1::Backup>

A list of backups. Corresponds to the JSON property backups



3685
3686
3687
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3685

def backups
  @backups
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, then there aren't subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3691
3692
3693
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3691

def next_page_token
  @next_page_token
end

#warningsArray<Google::Apis::SqladminV1::ApiWarning>

If a region isn't unavailable or if an unknown error occurs, then a warning message is returned. Corresponds to the JSON property warnings



3697
3698
3699
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3697

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3704
3705
3706
3707
3708
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3704

def update!(**args)
  @backups = args[:backups] if args.key?(:backups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warnings = args[:warnings] if args.key?(:warnings)
end