Class: Google::Apis::SqladminV1::LocationPreference
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::LocationPreference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Preferred location. This specifies where a Cloud SQL instance is located. Note that if the preferred location is not available, the instance will be located as close as possible within the region. Only one location may be specified.
Instance Attribute Summary collapse
-
#follow_gae_application ⇒ String
The App Engine application to follow, it must be in the same region as the Cloud SQL instance.
-
#kind ⇒ String
This is always
sql#locationPreference. -
#secondary_zone ⇒ String
The preferred Compute Engine zone for the secondary/failover (for example: us- central1-a, us-central1-b, etc.).
-
#zone ⇒ String
The preferred Compute Engine zone (for example: us-central1-a, us-central1-b, etc.).
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocationPreference
constructor
A new instance of LocationPreference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocationPreference
Returns a new instance of LocationPreference.
3753 3754 3755 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3753 def initialize(**args) update!(**args) end |
Instance Attribute Details
#follow_gae_application ⇒ String
The App Engine application to follow, it must be in the same region as the
Cloud SQL instance. WARNING: Changing this might restart the instance.
Corresponds to the JSON property followGaeApplication
3733 3734 3735 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3733 def follow_gae_application @follow_gae_application end |
#kind ⇒ String
This is always sql#locationPreference.
Corresponds to the JSON property kind
3738 3739 3740 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3738 def kind @kind end |
#secondary_zone ⇒ String
The preferred Compute Engine zone for the secondary/failover (for example: us-
central1-a, us-central1-b, etc.). To disable this field, set it to '
no_secondary_zone'.
Corresponds to the JSON property secondaryZone
3745 3746 3747 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3745 def secondary_zone @secondary_zone end |
#zone ⇒ String
The preferred Compute Engine zone (for example: us-central1-a, us-central1-b,
etc.). WARNING: Changing this might restart the instance.
Corresponds to the JSON property zone
3751 3752 3753 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3751 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3758 3759 3760 3761 3762 3763 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3758 def update!(**args) @follow_gae_application = args[:follow_gae_application] if args.key?(:follow_gae_application) @kind = args[:kind] if args.key?(:kind) @secondary_zone = args[:secondary_zone] if args.key?(:secondary_zone) @zone = args[:zone] if args.key?(:zone) end |