Class: Google::Apis::SqladminV1::LocationPreference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Preferred location. This specifies where a Cloud SQL instance is located. Note that if the preferred location is not available, the instance will be located as close as possible within the region. Only one location may be specified.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocationPreference

Returns a new instance of LocationPreference.



3732
3733
3734
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#follow_gae_applicationString

The App Engine application to follow, it must be in the same region as the Cloud SQL instance. WARNING: Changing this might restart the instance. Corresponds to the JSON property followGaeApplication

Returns:

  • (String)


3712
3713
3714
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3712

def follow_gae_application
  @follow_gae_application
end

#kindString

This is always sql#locationPreference. Corresponds to the JSON property kind

Returns:

  • (String)


3717
3718
3719
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3717

def kind
  @kind
end

#secondary_zoneString

The preferred Compute Engine zone for the secondary/failover (for example: us- central1-a, us-central1-b, etc.). To disable this field, set it to ' no_secondary_zone'. Corresponds to the JSON property secondaryZone

Returns:

  • (String)


3724
3725
3726
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3724

def secondary_zone
  @secondary_zone
end

#zoneString

The preferred Compute Engine zone (for example: us-central1-a, us-central1-b, etc.). WARNING: Changing this might restart the instance. Corresponds to the JSON property zone

Returns:

  • (String)


3730
3731
3732
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3730

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3737
3738
3739
3740
3741
3742
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3737

def update!(**args)
  @follow_gae_application = args[:follow_gae_application] if args.key?(:follow_gae_application)
  @kind = args[:kind] if args.key?(:kind)
  @secondary_zone = args[:secondary_zone] if args.key?(:secondary_zone)
  @zone = args[:zone] if args.key?(:zone)
end