Class: Google::Apis::SqladminV1::MySqlReplicaConfiguration
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::MySqlReplicaConfiguration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Read-replica configuration specific to MySQL databases.
Instance Attribute Summary collapse
-
#ca_certificate ⇒ String
PEM representation of the trusted CA's x509 certificate.
-
#client_certificate ⇒ String
PEM representation of the replica's x509 certificate.
-
#client_key ⇒ String
PEM representation of the replica's private key.
-
#connect_retry_interval ⇒ Fixnum
Seconds to wait between connect retries.
-
#dump_file_path ⇒ String
Path to a SQL dump file in Google Cloud Storage from which the replica instance is to be created.
-
#kind ⇒ String
This is always
sql#mysqlReplicaConfiguration. -
#master_heartbeat_period ⇒ Fixnum
Interval in milliseconds between replication heartbeats.
-
#password ⇒ String
The password for the replication connection.
-
#ssl_cipher ⇒ String
A list of permissible ciphers to use for SSL encryption.
-
#username ⇒ String
The username for the replication connection.
-
#verify_server_certificate ⇒ Boolean
(also: #verify_server_certificate?)
Whether or not to check the primary instance's Common Name value in the certificate that it sends during the SSL handshake.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MySqlReplicaConfiguration
constructor
A new instance of MySqlReplicaConfiguration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MySqlReplicaConfiguration
Returns a new instance of MySqlReplicaConfiguration.
3922 3923 3924 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3922 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ca_certificate ⇒ String
PEM representation of the trusted CA's x509 certificate.
Corresponds to the JSON property caCertificate
3863 3864 3865 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3863 def ca_certificate @ca_certificate end |
#client_certificate ⇒ String
PEM representation of the replica's x509 certificate.
Corresponds to the JSON property clientCertificate
3868 3869 3870 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3868 def client_certificate @client_certificate end |
#client_key ⇒ String
PEM representation of the replica's private key. The corresponding public key
is encoded in the client's certificate.
Corresponds to the JSON property clientKey
3874 3875 3876 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3874 def client_key @client_key end |
#connect_retry_interval ⇒ Fixnum
Seconds to wait between connect retries. MySQL's default is 60 seconds.
Corresponds to the JSON property connectRetryInterval
3879 3880 3881 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3879 def connect_retry_interval @connect_retry_interval end |
#dump_file_path ⇒ String
Path to a SQL dump file in Google Cloud Storage from which the replica
instance is to be created. The URI is in the form gs://bucketName/fileName.
Compressed gzip files (.gz) are also supported. Dumps have the binlog co-
ordinates from which replication begins. This can be accomplished by setting --
master-data to 1 when using mysqldump.
Corresponds to the JSON property dumpFilePath
3888 3889 3890 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3888 def dump_file_path @dump_file_path end |
#kind ⇒ String
This is always sql#mysqlReplicaConfiguration.
Corresponds to the JSON property kind
3893 3894 3895 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3893 def kind @kind end |
#master_heartbeat_period ⇒ Fixnum
Interval in milliseconds between replication heartbeats.
Corresponds to the JSON property masterHeartbeatPeriod
3898 3899 3900 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3898 def master_heartbeat_period @master_heartbeat_period end |
#password ⇒ String
The password for the replication connection.
Corresponds to the JSON property password
3903 3904 3905 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3903 def password @password end |
#ssl_cipher ⇒ String
A list of permissible ciphers to use for SSL encryption.
Corresponds to the JSON property sslCipher
3908 3909 3910 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3908 def ssl_cipher @ssl_cipher end |
#username ⇒ String
The username for the replication connection.
Corresponds to the JSON property username
3913 3914 3915 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3913 def username @username end |
#verify_server_certificate ⇒ Boolean Also known as: verify_server_certificate?
Whether or not to check the primary instance's Common Name value in the
certificate that it sends during the SSL handshake.
Corresponds to the JSON property verifyServerCertificate
3919 3920 3921 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3919 def verify_server_certificate @verify_server_certificate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 3939 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3927 def update!(**args) @ca_certificate = args[:ca_certificate] if args.key?(:ca_certificate) @client_certificate = args[:client_certificate] if args.key?(:client_certificate) @client_key = args[:client_key] if args.key?(:client_key) @connect_retry_interval = args[:connect_retry_interval] if args.key?(:connect_retry_interval) @dump_file_path = args[:dump_file_path] if args.key?(:dump_file_path) @kind = args[:kind] if args.key?(:kind) @master_heartbeat_period = args[:master_heartbeat_period] if args.key?(:master_heartbeat_period) @password = args[:password] if args.key?(:password) @ssl_cipher = args[:ssl_cipher] if args.key?(:ssl_cipher) @username = args[:username] if args.key?(:username) @verify_server_certificate = args[:verify_server_certificate] if args.key?(:verify_server_certificate) end |