Class: Google::Apis::SqladminV1::OnPremisesConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

On-premises instance configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OnPremisesConfiguration

Returns a new instance of OnPremisesConfiguration.



4001
4002
4003
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ca_certificateString

PEM representation of the trusted CA's x509 certificate. Corresponds to the JSON property caCertificate

Returns:

  • (String)


3947
3948
3949
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3947

def ca_certificate
  @ca_certificate
end

#client_certificateString

PEM representation of the replica's x509 certificate. Corresponds to the JSON property clientCertificate

Returns:

  • (String)


3952
3953
3954
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3952

def client_certificate
  @client_certificate
end

#client_keyString

PEM representation of the replica's private key. The corresponding public key is encoded in the client's certificate. Corresponds to the JSON property clientKey

Returns:

  • (String)


3958
3959
3960
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3958

def client_key
  @client_key
end

#dump_file_pathString

The dump file to create the Cloud SQL replica. Corresponds to the JSON property dumpFilePath

Returns:

  • (String)


3963
3964
3965
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3963

def dump_file_path
  @dump_file_path
end

#host_portString

The host and port of the on-premises instance in host:port format Corresponds to the JSON property hostPort

Returns:

  • (String)


3968
3969
3970
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3968

def host_port
  @host_port
end

#kindString

This is always sql#onPremisesConfiguration. Corresponds to the JSON property kind

Returns:

  • (String)


3973
3974
3975
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3973

def kind
  @kind
end

#passwordString

The password for connecting to on-premises instance. Corresponds to the JSON property password

Returns:

  • (String)


3978
3979
3980
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3978

def password
  @password
end

#selected_objectsArray<Google::Apis::SqladminV1::SelectedObjects>

Optional. A list of objects that the user selects for replication from an external source instance. Corresponds to the JSON property selectedObjects



3984
3985
3986
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3984

def selected_objects
  @selected_objects
end

#source_instanceGoogle::Apis::SqladminV1::InstanceReference

Reference to another Cloud SQL instance. Corresponds to the JSON property sourceInstance



3989
3990
3991
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3989

def source_instance
  @source_instance
end

#ssl_optionString

Optional. SSL option for replica connection to the on-premises source. Corresponds to the JSON property sslOption

Returns:

  • (String)


3994
3995
3996
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3994

def ssl_option
  @ssl_option
end

#usernameString

The username for connecting to on-premises instance. Corresponds to the JSON property username

Returns:

  • (String)


3999
4000
4001
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 3999

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4006

def update!(**args)
  @ca_certificate = args[:ca_certificate] if args.key?(:ca_certificate)
  @client_certificate = args[:client_certificate] if args.key?(:client_certificate)
  @client_key = args[:client_key] if args.key?(:client_key)
  @dump_file_path = args[:dump_file_path] if args.key?(:dump_file_path)
  @host_port = args[:host_port] if args.key?(:host_port)
  @kind = args[:kind] if args.key?(:kind)
  @password = args[:password] if args.key?(:password)
  @selected_objects = args[:selected_objects] if args.key?(:selected_objects)
  @source_instance = args[:source_instance] if args.key?(:source_instance)
  @ssl_option = args[:ssl_option] if args.key?(:ssl_option)
  @username = args[:username] if args.key?(:username)
end