Class: Google::Apis::SqladminV1::Operation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

An Operation resource. For successful operations that return an Operation resource, only the fields relevant to the operation are populated in the resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



4134
4135
4136
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4134

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acquire_ssrs_lease_contextGoogle::Apis::SqladminV1::AcquireSsrsLeaseContext

Acquire SSRS lease context. Corresponds to the JSON property acquireSsrsLeaseContext



4030
4031
4032
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4030

def acquire_ssrs_lease_context
  @acquire_ssrs_lease_context
end

#api_warningGoogle::Apis::SqladminV1::ApiWarning

An Admin API warning message. Corresponds to the JSON property apiWarning



4035
4036
4037
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4035

def api_warning
  @api_warning
end

#backup_contextGoogle::Apis::SqladminV1::BackupContext

Backup context. Corresponds to the JSON property backupContext



4040
4041
4042
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4040

def backup_context
  @backup_context
end

#end_timeString

The time this operation finished in UTC timezone in RFC 3339 format, for example 2012-11-15T16:19:00.094Z. Corresponds to the JSON property endTime

Returns:

  • (String)


4046
4047
4048
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4046

def end_time
  @end_time
end

#errorGoogle::Apis::SqladminV1::OperationErrors

Database instance operation errors list wrapper. Corresponds to the JSON property error



4051
4052
4053
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4051

def error
  @error
end

#export_contextGoogle::Apis::SqladminV1::ExportContext

Database instance export context. Corresponds to the JSON property exportContext



4056
4057
4058
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4056

def export_context
  @export_context
end

#import_contextGoogle::Apis::SqladminV1::ImportContext

Database instance import context. Corresponds to the JSON property importContext



4061
4062
4063
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4061

def import_context
  @import_context
end

#insert_timeString

The time this operation was enqueued in UTC timezone in RFC 3339 format, for example 2012-11-15T16:19:00.094Z. Corresponds to the JSON property insertTime

Returns:

  • (String)


4067
4068
4069
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4067

def insert_time
  @insert_time
end

#kindString

This is always sql#operation. Corresponds to the JSON property kind

Returns:

  • (String)


4072
4073
4074
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4072

def kind
  @kind
end

#nameString

An identifier that uniquely identifies the operation. You can use this identifier to retrieve the Operations resource that has information about the operation. Corresponds to the JSON property name

Returns:

  • (String)


4079
4080
4081
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4079

def name
  @name
end

#operation_typeString

The type of the operation. Valid values are: * CREATE * DELETE * UPDATE * RESTART * IMPORT * EXPORT * BACKUP_VOLUME * RESTORE_VOLUME * CREATE_USER * DELETE_USER * CREATE_DATABASE * DELETE_DATABASE Corresponds to the JSON property operationType

Returns:

  • (String)


4086
4087
4088
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4086

def operation_type
  @operation_type
end

#pre_check_major_version_upgrade_contextGoogle::Apis::SqladminV1::PreCheckMajorVersionUpgradeContext

Pre-check major version upgrade context. Corresponds to the JSON property preCheckMajorVersionUpgradeContext



4091
4092
4093
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4091

def pre_check_major_version_upgrade_context
  @pre_check_major_version_upgrade_context
end

The URI of this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4096
4097
4098
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4096

def self_link
  @self_link
end

#start_timeString

The time this operation actually started in UTC timezone in RFC 3339 format, for example 2012-11-15T16:19:00.094Z. Corresponds to the JSON property startTime

Returns:

  • (String)


4102
4103
4104
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4102

def start_time
  @start_time
end

#statusString

The status of an operation. Corresponds to the JSON property status

Returns:

  • (String)


4107
4108
4109
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4107

def status
  @status
end

#sub_operation_typeGoogle::Apis::SqladminV1::SqlSubOperationType

The sub operation type based on the operation type. Corresponds to the JSON property subOperationType



4112
4113
4114
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4112

def sub_operation_type
  @sub_operation_type
end

#target_idString

Name of the resource on which this operation runs. Corresponds to the JSON property targetId

Returns:

  • (String)


4117
4118
4119
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4117

def target_id
  @target_id
end

Corresponds to the JSON property targetLink

Returns:

  • (String)


4122
4123
4124
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4122

def target_link
  @target_link
end

#target_projectString

The project ID of the target instance related to this operation. Corresponds to the JSON property targetProject

Returns:

  • (String)


4127
4128
4129
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4127

def target_project
  @target_project
end

#userString

The email address of the user who initiated this operation. Corresponds to the JSON property user

Returns:

  • (String)


4132
4133
4134
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4132

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4139
4140
4141
4142
4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
4156
4157
4158
4159
4160
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4139

def update!(**args)
  @acquire_ssrs_lease_context = args[:acquire_ssrs_lease_context] if args.key?(:acquire_ssrs_lease_context)
  @api_warning = args[:api_warning] if args.key?(:api_warning)
  @backup_context = args[:backup_context] if args.key?(:backup_context)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @export_context = args[:export_context] if args.key?(:export_context)
  @import_context = args[:import_context] if args.key?(:import_context)
  @insert_time = args[:insert_time] if args.key?(:insert_time)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @operation_type = args[:operation_type] if args.key?(:operation_type)
  @pre_check_major_version_upgrade_context = args[:pre_check_major_version_upgrade_context] if args.key?(:pre_check_major_version_upgrade_context)
  @self_link = args[:self_link] if args.key?(:self_link)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @sub_operation_type = args[:sub_operation_type] if args.key?(:sub_operation_type)
  @target_id = args[:target_id] if args.key?(:target_id)
  @target_link = args[:target_link] if args.key?(:target_link)
  @target_project = args[:target_project] if args.key?(:target_project)
  @user = args[:user] if args.key?(:user)
end