Class: Google::Apis::SqladminV1::PerformanceCaptureConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Performance capture configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PerformanceCaptureConfig

Returns a new instance of PerformanceCaptureConfig.



4459
4460
4461
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4459

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Optional. Enables or disables the performance capture feature. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


4426
4427
4428
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4426

def enabled
  @enabled
end

#probe_thresholdFixnum

Optional. Specifies the minimum number of consecutive probe threshold that triggers performance capture. Corresponds to the JSON property probeThreshold

Returns:

  • (Fixnum)


4433
4434
4435
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4433

def probe_threshold
  @probe_threshold
end

#probing_interval_secondsFixnum

Optional. Specifies the interval in seconds between consecutive probes that check if any trigger condition thresholds have been reached. Corresponds to the JSON property probingIntervalSeconds

Returns:

  • (Fixnum)


4439
4440
4441
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4439

def probing_interval_seconds
  @probing_interval_seconds
end

#running_threads_thresholdFixnum

Optional. Specifies the minimum number of MySQL Threads_running to trigger the performance capture on the primary instance. Corresponds to the JSON property runningThreadsThreshold

Returns:

  • (Fixnum)


4445
4446
4447
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4445

def running_threads_threshold
  @running_threads_threshold
end

#seconds_behind_source_thresholdFixnum

Optional. Specifies the minimum number of seconds replica must be lagging behind primary instance to trigger the performance capture on replica. Corresponds to the JSON property secondsBehindSourceThreshold

Returns:

  • (Fixnum)


4451
4452
4453
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4451

def seconds_behind_source_threshold
  @seconds_behind_source_threshold
end

#transaction_duration_thresholdFixnum

Optional. Specifies the amount of time in seconds that a transaction needs to have been open before the watcher starts recording it. Corresponds to the JSON property transactionDurationThreshold

Returns:

  • (Fixnum)


4457
4458
4459
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4457

def transaction_duration_threshold
  @transaction_duration_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4464
4465
4466
4467
4468
4469
4470
4471
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4464

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @probe_threshold = args[:probe_threshold] if args.key?(:probe_threshold)
  @probing_interval_seconds = args[:probing_interval_seconds] if args.key?(:probing_interval_seconds)
  @running_threads_threshold = args[:running_threads_threshold] if args.key?(:running_threads_threshold)
  @seconds_behind_source_threshold = args[:seconds_behind_source_threshold] if args.key?(:seconds_behind_source_threshold)
  @transaction_duration_threshold = args[:transaction_duration_threshold] if args.key?(:transaction_duration_threshold)
end