Class: Google::Apis::SqladminV1::PointInTimeRestoreContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::PointInTimeRestoreContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
The context to perform a point-in-time recovery of an instance managed by Backup and Disaster Recovery (DR) Service.
Instance Attribute Summary collapse
-
#allocated_ip_range ⇒ String
Optional.
-
#datasource ⇒ String
The Backup and Disaster Recovery (DR) Service Datasource URI.
-
#point_in_time ⇒ String
Required.
-
#preferred_secondary_zone ⇒ String
Optional.
-
#preferred_zone ⇒ String
Optional.
-
#private_network ⇒ String
Optional.
-
#region ⇒ String
Optional.
-
#target_instance ⇒ String
Target instance name.
-
#target_instance_clear_settings_field_names ⇒ Array<String>
Optional.
-
#target_instance_settings ⇒ Google::Apis::SqladminV1::DatabaseInstance
A Cloud SQL instance resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PointInTimeRestoreContext
constructor
A new instance of PointInTimeRestoreContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PointInTimeRestoreContext
Returns a new instance of PointInTimeRestoreContext.
4623 4624 4625 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4623 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocated_ip_range ⇒ String
Optional. The name of the allocated IP range for the internal IP Cloud SQL
instance. For example: "google-managed-services-default". If you set this,
then Cloud SQL creates the IP address for the cloned instance in the allocated
range. This range must comply with RFC 1035 standards. Specifically, the name must be 1-63 characters long and
match the regular expression a-z?. Reserved for future
use.
Corresponds to the JSON property allocatedIpRange
4567 4568 4569 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4567 def allocated_ip_range @allocated_ip_range end |
#datasource ⇒ String
The Backup and Disaster Recovery (DR) Service Datasource URI. Format: projects/
project/locations/region/backupVaults/backupvault/dataSources/
datasource.
Corresponds to the JSON property datasource
4574 4575 4576 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4574 def datasource @datasource end |
#point_in_time ⇒ String
Required. The date and time to which you want to restore the instance.
Corresponds to the JSON property pointInTime
4579 4580 4581 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4579 def point_in_time @point_in_time end |
#preferred_secondary_zone ⇒ String
Optional. Point-in-time recovery of a regional instance in the specified zones.
If not specified, clone to the same secondary zone as the source instance.
This value cannot be the same as the preferred_zone field.
Corresponds to the JSON property preferredSecondaryZone
4586 4587 4588 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4586 def preferred_secondary_zone @preferred_secondary_zone end |
#preferred_zone ⇒ String
Optional. Point-in-time recovery of an instance to the specified zone. If no
zone is specified, then clone to the same primary zone as the source instance.
Corresponds to the JSON property preferredZone
4592 4593 4594 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4592 def preferred_zone @preferred_zone end |
#private_network ⇒ String
Optional. The resource link for the VPC network from which the Cloud SQL
instance is accessible for private IP. For example, /projects/myProject/
global/networks/default.
Corresponds to the JSON property privateNetwork
4599 4600 4601 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4599 def private_network @private_network end |
#region ⇒ String
Optional. The region of the target instance where the datasource will be
restored. For example: "us-central1".
Corresponds to the JSON property region
4605 4606 4607 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4605 def region @region end |
#target_instance ⇒ String
Target instance name.
Corresponds to the JSON property targetInstance
4610 4611 4612 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4610 def target_instance @target_instance end |
#target_instance_clear_settings_field_names ⇒ Array<String>
Optional. Specifies the instance settings that will be cleared from the source
instance. This field is only applicable for cross project PITRs.
Corresponds to the JSON property targetInstanceClearSettingsFieldNames
4616 4617 4618 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4616 def target_instance_clear_settings_field_names @target_instance_clear_settings_field_names end |
#target_instance_settings ⇒ Google::Apis::SqladminV1::DatabaseInstance
A Cloud SQL instance resource.
Corresponds to the JSON property targetInstanceSettings
4621 4622 4623 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4621 def target_instance_settings @target_instance_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4628 def update!(**args) @allocated_ip_range = args[:allocated_ip_range] if args.key?(:allocated_ip_range) @datasource = args[:datasource] if args.key?(:datasource) @point_in_time = args[:point_in_time] if args.key?(:point_in_time) @preferred_secondary_zone = args[:preferred_secondary_zone] if args.key?(:preferred_secondary_zone) @preferred_zone = args[:preferred_zone] if args.key?(:preferred_zone) @private_network = args[:private_network] if args.key?(:private_network) @region = args[:region] if args.key?(:region) @target_instance = args[:target_instance] if args.key?(:target_instance) @target_instance_clear_settings_field_names = args[:target_instance_clear_settings_field_names] if args.key?(:target_instance_clear_settings_field_names) @target_instance_settings = args[:target_instance_settings] if args.key?(:target_instance_settings) end |