Class: Google::Apis::SqladminV1::PointInTimeRestoreContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::PointInTimeRestoreContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
The context to perform a point-in-time recovery of an instance managed by Backup and Disaster Recovery (DR) Service.
Instance Attribute Summary collapse
-
#allocated_ip_range ⇒ String
Optional.
-
#datasource ⇒ String
The Backup and Disaster Recovery (DR) Service Datasource URI.
-
#point_in_time ⇒ String
Required.
-
#preferred_secondary_zone ⇒ String
Optional.
-
#preferred_zone ⇒ String
Optional.
-
#private_network ⇒ String
Optional.
-
#target_instance ⇒ String
Target instance name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PointInTimeRestoreContext
constructor
A new instance of PointInTimeRestoreContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PointInTimeRestoreContext
Returns a new instance of PointInTimeRestoreContext.
4526 4527 4528 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4526 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocated_ip_range ⇒ String
Optional. The name of the allocated IP range for the internal IP Cloud SQL
instance. For example: "google-managed-services-default". If you set this,
then Cloud SQL creates the IP address for the cloned instance in the allocated
range. This range must comply with RFC 1035 standards. Specifically, the name must be 1-63 characters long and
match the regular expression a-z?. Reserved for future
use.
Corresponds to the JSON property allocatedIpRange
4487 4488 4489 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4487 def allocated_ip_range @allocated_ip_range end |
#datasource ⇒ String
The Backup and Disaster Recovery (DR) Service Datasource URI. Format: projects/
project/locations/region/backupVaults/backupvault/dataSources/
datasource.
Corresponds to the JSON property datasource
4494 4495 4496 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4494 def datasource @datasource end |
#point_in_time ⇒ String
Required. The date and time to which you want to restore the instance.
Corresponds to the JSON property pointInTime
4499 4500 4501 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4499 def point_in_time @point_in_time end |
#preferred_secondary_zone ⇒ String
Optional. Point-in-time recovery of a regional instance in the specified zones.
If not specified, clone to the same secondary zone as the source instance.
This value cannot be the same as the preferred_zone field.
Corresponds to the JSON property preferredSecondaryZone
4506 4507 4508 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4506 def preferred_secondary_zone @preferred_secondary_zone end |
#preferred_zone ⇒ String
Optional. Point-in-time recovery of an instance to the specified zone. If no
zone is specified, then clone to the same primary zone as the source instance.
Corresponds to the JSON property preferredZone
4512 4513 4514 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4512 def preferred_zone @preferred_zone end |
#private_network ⇒ String
Optional. The resource link for the VPC network from which the Cloud SQL
instance is accessible for private IP. For example, /projects/myProject/
global/networks/default.
Corresponds to the JSON property privateNetwork
4519 4520 4521 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4519 def private_network @private_network end |
#target_instance ⇒ String
Target instance name.
Corresponds to the JSON property targetInstance
4524 4525 4526 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4524 def target_instance @target_instance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4531 4532 4533 4534 4535 4536 4537 4538 4539 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4531 def update!(**args) @allocated_ip_range = args[:allocated_ip_range] if args.key?(:allocated_ip_range) @datasource = args[:datasource] if args.key?(:datasource) @point_in_time = args[:point_in_time] if args.key?(:point_in_time) @preferred_secondary_zone = args[:preferred_secondary_zone] if args.key?(:preferred_secondary_zone) @preferred_zone = args[:preferred_zone] if args.key?(:preferred_zone) @private_network = args[:private_network] if args.key?(:private_network) @target_instance = args[:target_instance] if args.key?(:target_instance) end |