Class: Google::Apis::SqladminV1::PoolNodeConfig
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::PoolNodeConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Details of a single read pool node of a read pool.
Instance Attribute Summary collapse
-
#dns_name ⇒ String
Output only.
-
#dns_names ⇒ Array<Google::Apis::SqladminV1::DnsNameMapping>
Output only.
-
#gce_zone ⇒ String
Output only.
-
#ip_addresses ⇒ Array<Google::Apis::SqladminV1::IpMapping>
Output only.
-
#name ⇒ String
Output only.
-
#psc_auto_connections ⇒ Array<Google::Apis::SqladminV1::PscAutoConnectionConfig>
Output only.
-
#psc_service_attachment_link ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PoolNodeConfig
constructor
A new instance of PoolNodeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PoolNodeConfig
Returns a new instance of PoolNodeConfig.
4611 4612 4613 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4611 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dns_name ⇒ String
Output only. The DNS name of the read pool node.
Corresponds to the JSON property dnsName
4569 4570 4571 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4569 def dns_name @dns_name end |
#dns_names ⇒ Array<Google::Apis::SqladminV1::DnsNameMapping>
Output only. The list of DNS names used by this read pool node.
Corresponds to the JSON property dnsNames
4574 4575 4576 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4574 def dns_names @dns_names end |
#gce_zone ⇒ String
Output only. The zone of the read pool node.
Corresponds to the JSON property gceZone
4579 4580 4581 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4579 def gce_zone @gce_zone end |
#ip_addresses ⇒ Array<Google::Apis::SqladminV1::IpMapping>
Output only. Mappings containing IP addresses that can be used to connect to
the read pool node.
Corresponds to the JSON property ipAddresses
4585 4586 4587 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4585 def ip_addresses @ip_addresses end |
#name ⇒ String
Output only. The name of the read pool node, to be used for retrieving metrics
and logs.
Corresponds to the JSON property name
4591 4592 4593 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4591 def name @name end |
#psc_auto_connections ⇒ Array<Google::Apis::SqladminV1::PscAutoConnectionConfig>
Output only. The list of settings for requested automatically-setup Private
Service Connect (PSC) consumer endpoints that can be used to connect to this
read pool node.
Corresponds to the JSON property pscAutoConnections
4598 4599 4600 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4598 def psc_auto_connections @psc_auto_connections end |
#psc_service_attachment_link ⇒ String
Output only. The Private Service Connect (PSC) service attachment of the read
pool node.
Corresponds to the JSON property pscServiceAttachmentLink
4604 4605 4606 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4604 def @psc_service_attachment_link end |
#state ⇒ String
Output only. The current state of the read pool node.
Corresponds to the JSON property state
4609 4610 4611 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4609 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4616 def update!(**args) @dns_name = args[:dns_name] if args.key?(:dns_name) @dns_names = args[:dns_names] if args.key?(:dns_names) @gce_zone = args[:gce_zone] if args.key?(:gce_zone) @ip_addresses = args[:ip_addresses] if args.key?(:ip_addresses) @name = args[:name] if args.key?(:name) @psc_auto_connections = args[:psc_auto_connections] if args.key?(:psc_auto_connections) @psc_service_attachment_link = args[:psc_service_attachment_link] if args.key?(:psc_service_attachment_link) @state = args[:state] if args.key?(:state) end |