Class: Google::Apis::SqladminV1::PreCheckResponse
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::PreCheckResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Structured PreCheckResponse containing message, type, and required actions.
Instance Attribute Summary collapse
-
#actions_required ⇒ Array<String>
The actions that the user needs to take.
-
#message ⇒ String
The message to be displayed to the user.
-
#message_type ⇒ String
The type of message whether it is an info, warning, or error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreCheckResponse
constructor
A new instance of PreCheckResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreCheckResponse
Returns a new instance of PreCheckResponse.
4678 4679 4680 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4678 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions_required ⇒ Array<String>
The actions that the user needs to take. Use repeated for multiple actions.
Corresponds to the JSON property actionsRequired
4666 4667 4668 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4666 def actions_required @actions_required end |
#message ⇒ String
The message to be displayed to the user.
Corresponds to the JSON property message
4671 4672 4673 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4671 def @message end |
#message_type ⇒ String
The type of message whether it is an info, warning, or error.
Corresponds to the JSON property messageType
4676 4677 4678 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4676 def @message_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4683 4684 4685 4686 4687 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4683 def update!(**args) @actions_required = args[:actions_required] if args.key?(:actions_required) @message = args[:message] if args.key?(:message) @message_type = args[:message_type] if args.key?(:message_type) end |