Class: Google::Apis::SqladminV1::PreCheckResponse
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::PreCheckResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Structured PreCheckResponse containing message, type, and required actions.
Instance Attribute Summary collapse
-
#actions_required ⇒ Array<String>
The actions that the user needs to take.
-
#message ⇒ String
The message to be displayed to the user.
-
#message_type ⇒ String
The type of message whether it is an info, warning, or error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreCheckResponse
constructor
A new instance of PreCheckResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreCheckResponse
Returns a new instance of PreCheckResponse.
4658 4659 4660 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4658 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions_required ⇒ Array<String>
The actions that the user needs to take. Use repeated for multiple actions.
Corresponds to the JSON property actionsRequired
4646 4647 4648 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4646 def actions_required @actions_required end |
#message ⇒ String
The message to be displayed to the user.
Corresponds to the JSON property message
4651 4652 4653 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4651 def @message end |
#message_type ⇒ String
The type of message whether it is an info, warning, or error.
Corresponds to the JSON property messageType
4656 4657 4658 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4656 def @message_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4663 4664 4665 4666 4667 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4663 def update!(**args) @actions_required = args[:actions_required] if args.key?(:actions_required) @message = args[:message] if args.key?(:message) @message_type = args[:message_type] if args.key?(:message_type) end |