Class: Google::Apis::SqladminV1::PscAutoConnectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::PscAutoConnectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Settings for an automatically-setup Private Service Connect consumer endpoint that is used to connect to a Cloud SQL instance.
Instance Attribute Summary collapse
-
#consumer_network ⇒ String
Optional.
-
#consumer_network_status ⇒ String
The connection policy status of the consumer network.
-
#consumer_project ⇒ String
Optional.
-
#ip_address ⇒ String
The IP address of the consumer endpoint.
-
#service_connection_policy ⇒ String
Output only.
-
#service_connection_policy_creation_result ⇒ String
Output only.
-
#status ⇒ String
The connection status of the consumer endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscAutoConnectionConfig
constructor
A new instance of PscAutoConnectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscAutoConnectionConfig
Returns a new instance of PscAutoConnectionConfig.
4739 4740 4741 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_network ⇒ String
Optional. The consumer network of this consumer endpoint. This must be a
resource path that includes both the host project and the network name. For
example, projects/project1/global/networks/network1. The consumer host
project of this network might be different from the consumer service project.
Corresponds to the JSON property consumerNetwork
4702 4703 4704 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4702 def consumer_network @consumer_network end |
#consumer_network_status ⇒ String
The connection policy status of the consumer network.
Corresponds to the JSON property consumerNetworkStatus
4707 4708 4709 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4707 def consumer_network_status @consumer_network_status end |
#consumer_project ⇒ String
Optional. This is the project ID of consumer service project of this consumer
endpoint. This is only applicable if consumer_network is a shared VPC
network.
Corresponds to the JSON property consumerProject
4714 4715 4716 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4714 def consumer_project @consumer_project end |
#ip_address ⇒ String
The IP address of the consumer endpoint.
Corresponds to the JSON property ipAddress
4719 4720 4721 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4719 def ip_address @ip_address end |
#service_connection_policy ⇒ String
Output only. The service connection policy created automatically for the
consumer network when psc_auto_connection_policy_enabled is true. It is in
the format of: projects/project/regions/region/serviceConnectionPolicies/
policy_id`Thepolicy_idis in format of$NETWORK-$RANDOM.
Corresponds to the JSON propertyserviceConnectionPolicy`
4727 4728 4729 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4727 def service_connection_policy @service_connection_policy end |
#service_connection_policy_creation_result ⇒ String
Output only. The status of service connection policy creation.
Corresponds to the JSON property serviceConnectionPolicyCreationResult
4732 4733 4734 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4732 def service_connection_policy_creation_result @service_connection_policy_creation_result end |
#status ⇒ String
The connection status of the consumer endpoint.
Corresponds to the JSON property status
4737 4738 4739 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4737 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4744 4745 4746 4747 4748 4749 4750 4751 4752 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4744 def update!(**args) @consumer_network = args[:consumer_network] if args.key?(:consumer_network) @consumer_network_status = args[:consumer_network_status] if args.key?(:consumer_network_status) @consumer_project = args[:consumer_project] if args.key?(:consumer_project) @ip_address = args[:ip_address] if args.key?(:ip_address) @service_connection_policy = args[:service_connection_policy] if args.key?(:service_connection_policy) @service_connection_policy_creation_result = args[:service_connection_policy_creation_result] if args.key?(:service_connection_policy_creation_result) @status = args[:status] if args.key?(:status) end |