Class: Google::Apis::SqladminV1::PscAutoConnectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::PscAutoConnectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Settings for an automatically-setup Private Service Connect consumer endpoint that is used to connect to a Cloud SQL instance.
Instance Attribute Summary collapse
-
#consumer_network ⇒ String
Optional.
-
#consumer_network_status ⇒ String
The connection policy status of the consumer network.
-
#consumer_project ⇒ String
Optional.
-
#ip_address ⇒ String
The IP address of the consumer endpoint.
-
#status ⇒ String
The connection status of the consumer endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscAutoConnectionConfig
constructor
A new instance of PscAutoConnectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscAutoConnectionConfig
Returns a new instance of PscAutoConnectionConfig.
4705 4706 4707 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4705 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_network ⇒ String
Optional. The consumer network of this consumer endpoint. This must be a
resource path that includes both the host project and the network name. For
example, projects/project1/global/networks/network1. The consumer host
project of this network might be different from the consumer service project.
Corresponds to the JSON property consumerNetwork
4681 4682 4683 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4681 def consumer_network @consumer_network end |
#consumer_network_status ⇒ String
The connection policy status of the consumer network.
Corresponds to the JSON property consumerNetworkStatus
4686 4687 4688 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4686 def consumer_network_status @consumer_network_status end |
#consumer_project ⇒ String
Optional. This is the project ID of consumer service project of this consumer
endpoint. Optional. This is only applicable if consumer_network is a shared
vpc network.
Corresponds to the JSON property consumerProject
4693 4694 4695 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4693 def consumer_project @consumer_project end |
#ip_address ⇒ String
The IP address of the consumer endpoint.
Corresponds to the JSON property ipAddress
4698 4699 4700 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4698 def ip_address @ip_address end |
#status ⇒ String
The connection status of the consumer endpoint.
Corresponds to the JSON property status
4703 4704 4705 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4703 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4710 4711 4712 4713 4714 4715 4716 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4710 def update!(**args) @consumer_network = args[:consumer_network] if args.key?(:consumer_network) @consumer_network_status = args[:consumer_network_status] if args.key?(:consumer_network_status) @consumer_project = args[:consumer_project] if args.key?(:consumer_project) @ip_address = args[:ip_address] if args.key?(:ip_address) @status = args[:status] if args.key?(:status) end |