Class: Google::Apis::SqladminV1::QueryResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

QueryResult contains the result of executing a single SQL statement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryResult

Returns a new instance of QueryResult.



4970
4971
4972
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4970

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnsArray<Google::Apis::SqladminV1::Column>

List of columns included in the result. This also includes the data type of the column. Corresponds to the JSON property columns



4941
4942
4943
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4941

def columns
  @columns
end

#messageString

Message related to the SQL execution result. Corresponds to the JSON property message

Returns:

  • (String)


4946
4947
4948
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4946

def message
  @message
end

#partial_resultBoolean Also known as: partial_result?

Set to true if the SQL execution's result is truncated due to size limits or an error retrieving results. Corresponds to the JSON property partialResult

Returns:

  • (Boolean)


4952
4953
4954
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4952

def partial_result
  @partial_result
end

#rowsArray<Google::Apis::SqladminV1::Row>

Rows returned by the SQL statement. Corresponds to the JSON property rows

Returns:



4958
4959
4960
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4958

def rows
  @rows
end

#statusGoogle::Apis::SqladminV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



4968
4969
4970
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4968

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4975
4976
4977
4978
4979
4980
4981
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4975

def update!(**args)
  @columns = args[:columns] if args.key?(:columns)
  @message = args[:message] if args.key?(:message)
  @partial_result = args[:partial_result] if args.key?(:partial_result)
  @rows = args[:rows] if args.key?(:rows)
  @status = args[:status] if args.key?(:status)
end