Class: Google::Apis::SqladminV1::QueryResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

QueryResult contains the result of executing a single SQL statement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryResult

Returns a new instance of QueryResult.



4867
4868
4869
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnsArray<Google::Apis::SqladminV1::Column>

List of columns included in the result. This also includes the data type of the column. Corresponds to the JSON property columns



4838
4839
4840
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4838

def columns
  @columns
end

#messageString

Message related to the SQL execution result. Corresponds to the JSON property message

Returns:

  • (String)


4843
4844
4845
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4843

def message
  @message
end

#partial_resultBoolean Also known as: partial_result?

Set to true if the SQL execution's result is truncated due to size limits or an error retrieving results. Corresponds to the JSON property partialResult

Returns:

  • (Boolean)


4849
4850
4851
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4849

def partial_result
  @partial_result
end

#rowsArray<Google::Apis::SqladminV1::Row>

Rows returned by the SQL statement. Corresponds to the JSON property rows

Returns:



4855
4856
4857
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4855

def rows
  @rows
end

#statusGoogle::Apis::SqladminV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



4865
4866
4867
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4865

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4872
4873
4874
4875
4876
4877
4878
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4872

def update!(**args)
  @columns = args[:columns] if args.key?(:columns)
  @message = args[:message] if args.key?(:message)
  @partial_result = args[:partial_result] if args.key?(:partial_result)
  @rows = args[:rows] if args.key?(:rows)
  @status = args[:status] if args.key?(:status)
end