Class: Google::Apis::SqladminV1::QueryResult
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::QueryResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
QueryResult contains the result of executing a single SQL statement.
Instance Attribute Summary collapse
-
#columns ⇒ Array<Google::Apis::SqladminV1::Column>
List of columns included in the result.
-
#message ⇒ String
Message related to the SQL execution result.
-
#partial_result ⇒ Boolean
(also: #partial_result?)
Set to true if the SQL execution's result is truncated due to size limits or an error retrieving results.
-
#rows ⇒ Array<Google::Apis::SqladminV1::Row>
Rows returned by the SQL statement.
-
#status ⇒ Google::Apis::SqladminV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryResult
constructor
A new instance of QueryResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryResult
Returns a new instance of QueryResult.
4800 4801 4802 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4800 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Array<Google::Apis::SqladminV1::Column>
List of columns included in the result. This also includes the data type of
the column.
Corresponds to the JSON property columns
4771 4772 4773 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4771 def columns @columns end |
#message ⇒ String
Message related to the SQL execution result.
Corresponds to the JSON property message
4776 4777 4778 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4776 def @message end |
#partial_result ⇒ Boolean Also known as: partial_result?
Set to true if the SQL execution's result is truncated due to size limits or
an error retrieving results.
Corresponds to the JSON property partialResult
4782 4783 4784 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4782 def partial_result @partial_result end |
#rows ⇒ Array<Google::Apis::SqladminV1::Row>
Rows returned by the SQL statement.
Corresponds to the JSON property rows
4788 4789 4790 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4788 def rows @rows end |
#status ⇒ Google::Apis::SqladminV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
4798 4799 4800 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4798 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4805 4806 4807 4808 4809 4810 4811 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4805 def update!(**args) @columns = args[:columns] if args.key?(:columns) @message = args[:message] if args.key?(:message) @partial_result = args[:partial_result] if args.key?(:partial_result) @rows = args[:rows] if args.key?(:rows) @status = args[:status] if args.key?(:status) end |