Class: Google::Apis::SqladminV1::ReadPoolAutoScaleConfig
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::ReadPoolAutoScaleConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
The read pool auto-scale configuration.
Instance Attribute Summary collapse
-
#disable_scale_in ⇒ Boolean
(also: #disable_scale_in?)
Indicates whether read pool auto scaling supports scale in operations ( removing nodes).
-
#enabled ⇒ Boolean
(also: #enabled?)
Indicates whether read pool auto scaling is enabled.
-
#max_node_count ⇒ Fixnum
Maximum number of read pool nodes to be maintained.
-
#min_node_count ⇒ Fixnum
Minimum number of read pool nodes to be maintained.
-
#scale_in_cooldown_seconds ⇒ Fixnum
The cooldown period for scale-in operations.
-
#scale_out_cooldown_seconds ⇒ Fixnum
The cooldown period for scale-out operations.
-
#target_metrics ⇒ Array<Google::Apis::SqladminV1::TargetMetric>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReadPoolAutoScaleConfig
constructor
A new instance of ReadPoolAutoScaleConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReadPoolAutoScaleConfig
Returns a new instance of ReadPoolAutoScaleConfig.
4898 4899 4900 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4898 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disable_scale_in ⇒ Boolean Also known as: disable_scale_in?
Indicates whether read pool auto scaling supports scale in operations (
removing nodes).
Corresponds to the JSON property disableScaleIn
4864 4865 4866 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4864 def disable_scale_in @disable_scale_in end |
#enabled ⇒ Boolean Also known as: enabled?
Indicates whether read pool auto scaling is enabled.
Corresponds to the JSON property enabled
4870 4871 4872 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4870 def enabled @enabled end |
#max_node_count ⇒ Fixnum
Maximum number of read pool nodes to be maintained.
Corresponds to the JSON property maxNodeCount
4876 4877 4878 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4876 def max_node_count @max_node_count end |
#min_node_count ⇒ Fixnum
Minimum number of read pool nodes to be maintained.
Corresponds to the JSON property minNodeCount
4881 4882 4883 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4881 def min_node_count @min_node_count end |
#scale_in_cooldown_seconds ⇒ Fixnum
The cooldown period for scale-in operations.
Corresponds to the JSON property scaleInCooldownSeconds
4886 4887 4888 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4886 def scale_in_cooldown_seconds @scale_in_cooldown_seconds end |
#scale_out_cooldown_seconds ⇒ Fixnum
The cooldown period for scale-out operations.
Corresponds to the JSON property scaleOutCooldownSeconds
4891 4892 4893 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4891 def scale_out_cooldown_seconds @scale_out_cooldown_seconds end |
#target_metrics ⇒ Array<Google::Apis::SqladminV1::TargetMetric>
Optional. Target metrics for read pool auto scaling.
Corresponds to the JSON property targetMetrics
4896 4897 4898 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4896 def target_metrics @target_metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4903 4904 4905 4906 4907 4908 4909 4910 4911 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4903 def update!(**args) @disable_scale_in = args[:disable_scale_in] if args.key?(:disable_scale_in) @enabled = args[:enabled] if args.key?(:enabled) @max_node_count = args[:max_node_count] if args.key?(:max_node_count) @min_node_count = args[:min_node_count] if args.key?(:min_node_count) @scale_in_cooldown_seconds = args[:scale_in_cooldown_seconds] if args.key?(:scale_in_cooldown_seconds) @scale_out_cooldown_seconds = args[:scale_out_cooldown_seconds] if args.key?(:scale_out_cooldown_seconds) @target_metrics = args[:target_metrics] if args.key?(:target_metrics) end |