Class: Google::Apis::SqladminV1::ReadPoolAutoScaleConfig
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::ReadPoolAutoScaleConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
The read pool auto-scale configuration.
Instance Attribute Summary collapse
-
#disable_scale_in ⇒ Boolean
(also: #disable_scale_in?)
Indicates whether read pool auto scaling supports scale in operations ( removing nodes).
-
#enabled ⇒ Boolean
(also: #enabled?)
Indicates whether read pool auto scaling is enabled.
-
#max_node_count ⇒ Fixnum
Maximum number of read pool nodes to be maintained.
-
#min_node_count ⇒ Fixnum
Minimum number of read pool nodes to be maintained.
-
#scale_in_cooldown_seconds ⇒ Fixnum
The cooldown period for scale-in operations.
-
#scale_out_cooldown_seconds ⇒ Fixnum
The cooldown period for scale-out operations.
-
#target_metrics ⇒ Array<Google::Apis::SqladminV1::TargetMetric>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReadPoolAutoScaleConfig
constructor
A new instance of ReadPoolAutoScaleConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReadPoolAutoScaleConfig
Returns a new instance of ReadPoolAutoScaleConfig.
4856 4857 4858 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4856 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disable_scale_in ⇒ Boolean Also known as: disable_scale_in?
Indicates whether read pool auto scaling supports scale in operations (
removing nodes).
Corresponds to the JSON property disableScaleIn
4822 4823 4824 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4822 def disable_scale_in @disable_scale_in end |
#enabled ⇒ Boolean Also known as: enabled?
Indicates whether read pool auto scaling is enabled.
Corresponds to the JSON property enabled
4828 4829 4830 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4828 def enabled @enabled end |
#max_node_count ⇒ Fixnum
Maximum number of read pool nodes to be maintained.
Corresponds to the JSON property maxNodeCount
4834 4835 4836 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4834 def max_node_count @max_node_count end |
#min_node_count ⇒ Fixnum
Minimum number of read pool nodes to be maintained.
Corresponds to the JSON property minNodeCount
4839 4840 4841 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4839 def min_node_count @min_node_count end |
#scale_in_cooldown_seconds ⇒ Fixnum
The cooldown period for scale-in operations.
Corresponds to the JSON property scaleInCooldownSeconds
4844 4845 4846 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4844 def scale_in_cooldown_seconds @scale_in_cooldown_seconds end |
#scale_out_cooldown_seconds ⇒ Fixnum
The cooldown period for scale-out operations.
Corresponds to the JSON property scaleOutCooldownSeconds
4849 4850 4851 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4849 def scale_out_cooldown_seconds @scale_out_cooldown_seconds end |
#target_metrics ⇒ Array<Google::Apis::SqladminV1::TargetMetric>
Optional. Target metrics for read pool auto scaling.
Corresponds to the JSON property targetMetrics
4854 4855 4856 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4854 def target_metrics @target_metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4861 4862 4863 4864 4865 4866 4867 4868 4869 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 4861 def update!(**args) @disable_scale_in = args[:disable_scale_in] if args.key?(:disable_scale_in) @enabled = args[:enabled] if args.key?(:enabled) @max_node_count = args[:max_node_count] if args.key?(:max_node_count) @min_node_count = args[:min_node_count] if args.key?(:min_node_count) @scale_in_cooldown_seconds = args[:scale_in_cooldown_seconds] if args.key?(:scale_in_cooldown_seconds) @scale_out_cooldown_seconds = args[:scale_out_cooldown_seconds] if args.key?(:scale_out_cooldown_seconds) @target_metrics = args[:target_metrics] if args.key?(:target_metrics) end |