Class: Google::Apis::SqladminV1::RotateEntraIdCertificateContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::RotateEntraIdCertificateContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Instance rotate Entra ID certificate context.
Instance Attribute Summary collapse
-
#kind ⇒ String
Optional.
-
#next_version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RotateEntraIdCertificateContext
constructor
A new instance of RotateEntraIdCertificateContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RotateEntraIdCertificateContext
Returns a new instance of RotateEntraIdCertificateContext.
5203 5204 5205 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5203 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Optional. This is always sql#rotateEntraIdCertificateContext.
Corresponds to the JSON property kind
5194 5195 5196 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5194 def kind @kind end |
#next_version ⇒ String
Optional. The fingerprint of the next version to be rotated to. If left
unspecified, will be rotated to the most recently added server certificate
version.
Corresponds to the JSON property nextVersion
5201 5202 5203 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5201 def next_version @next_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5208 5209 5210 5211 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5208 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_version = args[:next_version] if args.key?(:next_version) end |