Class: Google::Apis::SqladminV1::RotateEntraIdCertificateContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::RotateEntraIdCertificateContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Instance rotate Entra ID certificate context.
Instance Attribute Summary collapse
-
#kind ⇒ String
Optional.
-
#next_version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RotateEntraIdCertificateContext
constructor
A new instance of RotateEntraIdCertificateContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RotateEntraIdCertificateContext
Returns a new instance of RotateEntraIdCertificateContext.
5045 5046 5047 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Optional. This is always sql#rotateEntraIdCertificateContext.
Corresponds to the JSON property kind
5036 5037 5038 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5036 def kind @kind end |
#next_version ⇒ String
Optional. The fingerprint of the next version to be rotated to. If left
unspecified, will be rotated to the most recently added server certificate
version.
Corresponds to the JSON property nextVersion
5043 5044 5045 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5043 def next_version @next_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5050 5051 5052 5053 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5050 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_version = args[:next_version] if args.key?(:next_version) end |