Class: Google::Apis::SqladminV1::RotateServerCaContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::RotateServerCaContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Instance rotate server CA context.
Instance Attribute Summary collapse
-
#kind ⇒ String
This is always
sql#rotateServerCaContext. -
#next_version ⇒ String
The fingerprint of the next version to be rotated to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RotateServerCaContext
constructor
A new instance of RotateServerCaContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RotateServerCaContext
Returns a new instance of RotateServerCaContext.
5229 5230 5231 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5229 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
This is always sql#rotateServerCaContext.
Corresponds to the JSON property kind
5221 5222 5223 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5221 def kind @kind end |
#next_version ⇒ String
The fingerprint of the next version to be rotated to. If left unspecified,
will be rotated to the most recently added server CA version.
Corresponds to the JSON property nextVersion
5227 5228 5229 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5227 def next_version @next_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5234 5235 5236 5237 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5234 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_version = args[:next_version] if args.key?(:next_version) end |