Class: Google::Apis::SqladminV1::RotateServerCaContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::RotateServerCaContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Instance rotate server CA context.
Instance Attribute Summary collapse
-
#kind ⇒ String
This is always
sql#rotateServerCaContext. -
#next_version ⇒ String
The fingerprint of the next version to be rotated to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RotateServerCaContext
constructor
A new instance of RotateServerCaContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RotateServerCaContext
Returns a new instance of RotateServerCaContext.
5114 5115 5116 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5114 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
This is always sql#rotateServerCaContext.
Corresponds to the JSON property kind
5106 5107 5108 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5106 def kind @kind end |
#next_version ⇒ String
The fingerprint of the next version to be rotated to. If left unspecified,
will be rotated to the most recently added server CA version.
Corresponds to the JSON property nextVersion
5112 5113 5114 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5112 def next_version @next_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5119 5120 5121 5122 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5119 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_version = args[:next_version] if args.key?(:next_version) end |