Class: Google::Apis::SqladminV1::RotateServerCaContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::RotateServerCaContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Instance rotate server CA context.
Instance Attribute Summary collapse
-
#kind ⇒ String
This is always
sql#rotateServerCaContext. -
#next_version ⇒ String
The fingerprint of the next version to be rotated to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RotateServerCaContext
constructor
A new instance of RotateServerCaContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RotateServerCaContext
Returns a new instance of RotateServerCaContext.
5071 5072 5073 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5071 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
This is always sql#rotateServerCaContext.
Corresponds to the JSON property kind
5063 5064 5065 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5063 def kind @kind end |
#next_version ⇒ String
The fingerprint of the next version to be rotated to. If left unspecified,
will be rotated to the most recently added server CA version.
Corresponds to the JSON property nextVersion
5069 5070 5071 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5069 def next_version @next_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5076 5077 5078 5079 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5076 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_version = args[:next_version] if args.key?(:next_version) end |