Class: Google::Apis::SqladminV1::RotateServerCertificateContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::RotateServerCertificateContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Instance rotate server certificate context.
Instance Attribute Summary collapse
-
#kind ⇒ String
Optional.
-
#next_version ⇒ String
The fingerprint of the next version to be rotated to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RotateServerCertificateContext
constructor
A new instance of RotateServerCertificateContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RotateServerCertificateContext
Returns a new instance of RotateServerCertificateContext.
5283 5284 5285 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5283 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Optional. This is always sql#rotateServerCertificateContext.
Corresponds to the JSON property kind
5275 5276 5277 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5275 def kind @kind end |
#next_version ⇒ String
The fingerprint of the next version to be rotated to. If left unspecified,
will be rotated to the most recently added server certificate version.
Corresponds to the JSON property nextVersion
5281 5282 5283 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5281 def next_version @next_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5288 5289 5290 5291 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5288 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_version = args[:next_version] if args.key?(:next_version) end |