Class: Google::Apis::SqladminV1::RotateServerCertificateContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Instance rotate server certificate context.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RotateServerCertificateContext

Returns a new instance of RotateServerCertificateContext.



5255
5256
5257
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Optional. This is always sql#rotateServerCertificateContext. Corresponds to the JSON property kind

Returns:

  • (String)


5247
5248
5249
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5247

def kind
  @kind
end

#next_versionString

The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added server certificate version. Corresponds to the JSON property nextVersion

Returns:

  • (String)


5253
5254
5255
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5253

def next_version
  @next_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5260
5261
5262
5263
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5260

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @next_version = args[:next_version] if args.key?(:next_version)
end