Class: Google::Apis::SqladminV1::RotateServerCertificateContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::RotateServerCertificateContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Instance rotate server certificate context.
Instance Attribute Summary collapse
-
#kind ⇒ String
Optional.
-
#next_version ⇒ String
The fingerprint of the next version to be rotated to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RotateServerCertificateContext
constructor
A new instance of RotateServerCertificateContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RotateServerCertificateContext
Returns a new instance of RotateServerCertificateContext.
5097 5098 5099 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Optional. This is always sql#rotateServerCertificateContext.
Corresponds to the JSON property kind
5089 5090 5091 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5089 def kind @kind end |
#next_version ⇒ String
The fingerprint of the next version to be rotated to. If left unspecified,
will be rotated to the most recently added server certificate version.
Corresponds to the JSON property nextVersion
5095 5096 5097 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5095 def next_version @next_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5102 5103 5104 5105 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5102 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_version = args[:next_version] if args.key?(:next_version) end |