Class: Google::Apis::SqladminV1::SqlInstancesExecuteSqlResponse
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::SqlInstancesExecuteSqlResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Execute SQL statements response.
Instance Attribute Summary collapse
-
#messages ⇒ Array<Google::Apis::SqladminV1::Message>
A list of notices and warnings generated during query execution.
-
#metadata ⇒ Google::Apis::SqladminV1::Metadata
The additional metadata information regarding the execution of the SQL statements.
-
#results ⇒ Array<Google::Apis::SqladminV1::QueryResult>
The list of results after executing all the SQL statements.
-
#status ⇒ Google::Apis::SqladminV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlInstancesExecuteSqlResponse
constructor
A new instance of SqlInstancesExecuteSqlResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlInstancesExecuteSqlResponse
Returns a new instance of SqlInstancesExecuteSqlResponse.
5789 5790 5791 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5789 def initialize(**args) update!(**args) end |
Instance Attribute Details
#messages ⇒ Array<Google::Apis::SqladminV1::Message>
A list of notices and warnings generated during query execution. For
PostgreSQL, this includes all notices and warnings. For MySQL, this includes
warnings generated by the last executed statement. To retrieve all warnings
for a multi-statement query, SHOW WARNINGS must be executed after each
statement.
Corresponds to the JSON property messages
5766 5767 5768 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5766 def @messages end |
#metadata ⇒ Google::Apis::SqladminV1::Metadata
The additional metadata information regarding the execution of the SQL
statements.
Corresponds to the JSON property metadata
5772 5773 5774 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5772 def @metadata end |
#results ⇒ Array<Google::Apis::SqladminV1::QueryResult>
The list of results after executing all the SQL statements.
Corresponds to the JSON property results
5777 5778 5779 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5777 def results @results end |
#status ⇒ Google::Apis::SqladminV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
5787 5788 5789 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5787 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5794 5795 5796 5797 5798 5799 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5794 def update!(**args) @messages = args[:messages] if args.key?(:messages) @metadata = args[:metadata] if args.key?(:metadata) @results = args[:results] if args.key?(:results) @status = args[:status] if args.key?(:status) end |