Class: Google::Apis::SqladminV1::SqlInstancesExecuteSqlResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Execute SQL statements response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlInstancesExecuteSqlResponse

Returns a new instance of SqlInstancesExecuteSqlResponse.



5698
5699
5700
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messagesArray<Google::Apis::SqladminV1::Message>

A list of notices and warnings generated during query execution. For PostgreSQL, this includes all notices and warnings. For MySQL, this includes warnings generated by the last executed statement. To retrieve all warnings for a multi-statement query, SHOW WARNINGS must be executed after each statement. Corresponds to the JSON property messages



5675
5676
5677
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5675

def messages
  @messages
end

#metadataGoogle::Apis::SqladminV1::Metadata

The additional metadata information regarding the execution of the SQL statements. Corresponds to the JSON property metadata



5681
5682
5683
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5681

def 
  @metadata
end

#resultsArray<Google::Apis::SqladminV1::QueryResult>

The list of results after executing all the SQL statements. Corresponds to the JSON property results



5686
5687
5688
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5686

def results
  @results
end

#statusGoogle::Apis::SqladminV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



5696
5697
5698
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5696

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5703
5704
5705
5706
5707
5708
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5703

def update!(**args)
  @messages = args[:messages] if args.key?(:messages)
  @metadata = args[:metadata] if args.key?(:metadata)
  @results = args[:results] if args.key?(:results)
  @status = args[:status] if args.key?(:status)
end