Class: Google::Apis::SqladminV1::SqlInstancesExecuteSqlResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Execute SQL statements response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlInstancesExecuteSqlResponse

Returns a new instance of SqlInstancesExecuteSqlResponse.



5631
5632
5633
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5631

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messagesArray<Google::Apis::SqladminV1::Message>

A list of notices and warnings generated during query execution. For PostgreSQL, this includes all notices and warnings. For MySQL, this includes warnings generated by the last executed statement. To retrieve all warnings for a multi-statement query, SHOW WARNINGS must be executed after each statement. Corresponds to the JSON property messages



5608
5609
5610
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5608

def messages
  @messages
end

#metadataGoogle::Apis::SqladminV1::Metadata

The additional metadata information regarding the execution of the SQL statements. Corresponds to the JSON property metadata



5614
5615
5616
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5614

def 
  @metadata
end

#resultsArray<Google::Apis::SqladminV1::QueryResult>

The list of results after executing all the SQL statements. Corresponds to the JSON property results



5619
5620
5621
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5619

def results
  @results
end

#statusGoogle::Apis::SqladminV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



5629
5630
5631
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5629

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5636
5637
5638
5639
5640
5641
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5636

def update!(**args)
  @messages = args[:messages] if args.key?(:messages)
  @metadata = args[:metadata] if args.key?(:metadata)
  @results = args[:results] if args.key?(:results)
  @status = args[:status] if args.key?(:status)
end