Class: Google::Apis::SqladminV1::SqlInstancesGetLatestRecoveryTimeResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Instance get latest recovery time response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlInstancesGetLatestRecoveryTimeResponse

Returns a new instance of SqlInstancesGetLatestRecoveryTimeResponse.



5761
5762
5763
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5761

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#earliest_recovery_timeString

Timestamp, identifies the earliest recovery time of the source instance. Corresponds to the JSON property earliestRecoveryTime

Returns:

  • (String)


5749
5750
5751
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5749

def earliest_recovery_time
  @earliest_recovery_time
end

#kindString

This is always sql#getLatestRecoveryTime. Corresponds to the JSON property kind

Returns:

  • (String)


5754
5755
5756
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5754

def kind
  @kind
end

#latest_recovery_timeString

Timestamp, identifies the latest recovery time of the source instance. Corresponds to the JSON property latestRecoveryTime

Returns:

  • (String)


5759
5760
5761
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5759

def latest_recovery_time
  @latest_recovery_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5766
5767
5768
5769
5770
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5766

def update!(**args)
  @earliest_recovery_time = args[:earliest_recovery_time] if args.key?(:earliest_recovery_time)
  @kind = args[:kind] if args.key?(:kind)
  @latest_recovery_time = args[:latest_recovery_time] if args.key?(:latest_recovery_time)
end