Class: Google::Apis::SqladminV1::SqlInstancesGetLatestRecoveryTimeResponse
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::SqlInstancesGetLatestRecoveryTimeResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Instance get latest recovery time response.
Instance Attribute Summary collapse
-
#earliest_recovery_time ⇒ String
Timestamp, identifies the earliest recovery time of the source instance.
-
#kind ⇒ String
This is always
sql#getLatestRecoveryTime. -
#latest_recovery_time ⇒ String
Timestamp, identifies the latest recovery time of the source instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlInstancesGetLatestRecoveryTimeResponse
constructor
A new instance of SqlInstancesGetLatestRecoveryTimeResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlInstancesGetLatestRecoveryTimeResponse
Returns a new instance of SqlInstancesGetLatestRecoveryTimeResponse.
5694 5695 5696 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5694 def initialize(**args) update!(**args) end |
Instance Attribute Details
#earliest_recovery_time ⇒ String
Timestamp, identifies the earliest recovery time of the source instance.
Corresponds to the JSON property earliestRecoveryTime
5682 5683 5684 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5682 def earliest_recovery_time @earliest_recovery_time end |
#kind ⇒ String
This is always sql#getLatestRecoveryTime.
Corresponds to the JSON property kind
5687 5688 5689 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5687 def kind @kind end |
#latest_recovery_time ⇒ String
Timestamp, identifies the latest recovery time of the source instance.
Corresponds to the JSON property latestRecoveryTime
5692 5693 5694 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5692 def latest_recovery_time @latest_recovery_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5699 5700 5701 5702 5703 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5699 def update!(**args) @earliest_recovery_time = args[:earliest_recovery_time] if args.key?(:earliest_recovery_time) @kind = args[:kind] if args.key?(:kind) @latest_recovery_time = args[:latest_recovery_time] if args.key?(:latest_recovery_time) end |