Class: Google::Apis::SqladminV1::SqlInstancesStartExternalSyncRequest
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::SqlInstancesStartExternalSyncRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
Instance start external sync request.
Instance Attribute Summary collapse
-
#migration_type ⇒ String
Optional.
-
#mysql_sync_config ⇒ Google::Apis::SqladminV1::MySqlSyncConfig
MySQL-specific external server sync settings.
-
#replica_overwrite_enabled ⇒ Boolean
(also: #replica_overwrite_enabled?)
Optional.
-
#skip_verification ⇒ Boolean
(also: #skip_verification?)
Whether to skip the verification step (VESS).
-
#sync_mode ⇒ String
External sync mode.
-
#sync_parallel_level ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlInstancesStartExternalSyncRequest
constructor
A new instance of SqlInstancesStartExternalSyncRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlInstancesStartExternalSyncRequest
Returns a new instance of SqlInstancesStartExternalSyncRequest.
5957 5958 5959 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5957 def initialize(**args) update!(**args) end |
Instance Attribute Details
#migration_type ⇒ String
Optional. MigrationType configures the migration to use physical files or
logical dump files. If not set, then the logical dump file configuration is
used. Valid values are LOGICAL or PHYSICAL. Only applicable to MySQL.
Corresponds to the JSON property migrationType
5924 5925 5926 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5924 def migration_type @migration_type end |
#mysql_sync_config ⇒ Google::Apis::SqladminV1::MySqlSyncConfig
MySQL-specific external server sync settings.
Corresponds to the JSON property mysqlSyncConfig
5929 5930 5931 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5929 def mysql_sync_config @mysql_sync_config end |
#replica_overwrite_enabled ⇒ Boolean Also known as: replica_overwrite_enabled?
Optional. MySQL only. True if end-user has confirmed that this SES call will
wipe replica databases overlapping with the proposed selected_objects. If this
field is not set and there are both overlapping and additional databases
proposed, an error will be returned.
Corresponds to the JSON property replicaOverwriteEnabled
5937 5938 5939 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5937 def replica_overwrite_enabled @replica_overwrite_enabled end |
#skip_verification ⇒ Boolean Also known as: skip_verification?
Whether to skip the verification step (VESS).
Corresponds to the JSON property skipVerification
5943 5944 5945 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5943 def skip_verification @skip_verification end |
#sync_mode ⇒ String
External sync mode.
Corresponds to the JSON property syncMode
5949 5950 5951 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5949 def sync_mode @sync_mode end |
#sync_parallel_level ⇒ String
Optional. Parallel level for initial data sync. Currently only applicable for
MySQL.
Corresponds to the JSON property syncParallelLevel
5955 5956 5957 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5955 def sync_parallel_level @sync_parallel_level end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5962 5963 5964 5965 5966 5967 5968 5969 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5962 def update!(**args) @migration_type = args[:migration_type] if args.key?(:migration_type) @mysql_sync_config = args[:mysql_sync_config] if args.key?(:mysql_sync_config) @replica_overwrite_enabled = args[:replica_overwrite_enabled] if args.key?(:replica_overwrite_enabled) @skip_verification = args[:skip_verification] if args.key?(:skip_verification) @sync_mode = args[:sync_mode] if args.key?(:sync_mode) @sync_parallel_level = args[:sync_parallel_level] if args.key?(:sync_parallel_level) end |