Class: Google::Apis::SqladminV1::SqlInstancesVerifyExternalSyncSettingsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Instance verify external sync settings request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlInstancesVerifyExternalSyncSettingsRequest

Returns a new instance of SqlInstancesVerifyExternalSyncSettingsRequest.



6016
6017
6018
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6016

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#migration_typeString

Optional. MigrationType configures the migration to use physical files or logical dump files. If not set, then the logical dump file configuration is used. Valid values are LOGICAL or PHYSICAL. Only applicable to MySQL. Corresponds to the JSON property migrationType

Returns:

  • (String)


5981
5982
5983
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5981

def migration_type
  @migration_type
end

#mysql_sync_configGoogle::Apis::SqladminV1::MySqlSyncConfig

MySQL-specific external server sync settings. Corresponds to the JSON property mysqlSyncConfig



5986
5987
5988
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5986

def mysql_sync_config
  @mysql_sync_config
end

#selected_objectsArray<Google::Apis::SqladminV1::ExternalSyncSelectedObject>

Optional. Migrate only the specified objects from the source instance. If this field is empty, then migrate all objects. Corresponds to the JSON property selectedObjects



5992
5993
5994
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5992

def selected_objects
  @selected_objects
end

#sync_modeString

External sync mode Corresponds to the JSON property syncMode

Returns:

  • (String)


5997
5998
5999
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 5997

def sync_mode
  @sync_mode
end

#sync_parallel_levelString

Optional. Parallel level for initial data sync. Only applicable for PostgreSQL. Corresponds to the JSON property syncParallelLevel

Returns:

  • (String)


6002
6003
6004
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6002

def sync_parallel_level
  @sync_parallel_level
end

#verify_connection_onlyBoolean Also known as: verify_connection_only?

Flag to enable verifying connection only Corresponds to the JSON property verifyConnectionOnly

Returns:

  • (Boolean)


6007
6008
6009
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6007

def verify_connection_only
  @verify_connection_only
end

#verify_replication_onlyBoolean Also known as: verify_replication_only?

Optional. Flag to verify settings required by replication setup only Corresponds to the JSON property verifyReplicationOnly

Returns:

  • (Boolean)


6013
6014
6015
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6013

def verify_replication_only
  @verify_replication_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6021
6022
6023
6024
6025
6026
6027
6028
6029
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6021

def update!(**args)
  @migration_type = args[:migration_type] if args.key?(:migration_type)
  @mysql_sync_config = args[:mysql_sync_config] if args.key?(:mysql_sync_config)
  @selected_objects = args[:selected_objects] if args.key?(:selected_objects)
  @sync_mode = args[:sync_mode] if args.key?(:sync_mode)
  @sync_parallel_level = args[:sync_parallel_level] if args.key?(:sync_parallel_level)
  @verify_connection_only = args[:verify_connection_only] if args.key?(:verify_connection_only)
  @verify_replication_only = args[:verify_replication_only] if args.key?(:verify_replication_only)
end