Class: Google::Apis::SqladminV1::SqlScheduledMaintenance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

Any scheduled maintenance for this instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlScheduledMaintenance

Returns a new instance of SqlScheduledMaintenance.



6118
6119
6120
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6118

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_deferBoolean Also known as: can_defer?

Corresponds to the JSON property canDefer

Returns:

  • (Boolean)


6099
6100
6101
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6099

def can_defer
  @can_defer
end

#can_rescheduleBoolean Also known as: can_reschedule?

If the scheduled maintenance can be rescheduled. Corresponds to the JSON property canReschedule

Returns:

  • (Boolean)


6105
6106
6107
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6105

def can_reschedule
  @can_reschedule
end

#schedule_deadline_timeString

Maintenance cannot be rescheduled to start beyond this deadline. Corresponds to the JSON property scheduleDeadlineTime

Returns:

  • (String)


6111
6112
6113
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6111

def schedule_deadline_time
  @schedule_deadline_time
end

#start_timeString

The start time of any upcoming scheduled maintenance for this instance. Corresponds to the JSON property startTime

Returns:

  • (String)


6116
6117
6118
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6116

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6123
6124
6125
6126
6127
6128
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6123

def update!(**args)
  @can_defer = args[:can_defer] if args.key?(:can_defer)
  @can_reschedule = args[:can_reschedule] if args.key?(:can_reschedule)
  @schedule_deadline_time = args[:schedule_deadline_time] if args.key?(:schedule_deadline_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end