Class: Google::Apis::SqladminV1::SslCert
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::SslCert
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
SslCerts Resource
Instance Attribute Summary collapse
-
#cert ⇒ String
PEM representation.
-
#cert_serial_number ⇒ String
Serial number, as extracted from the certificate.
-
#common_name ⇒ String
User supplied name.
-
#create_time ⇒ String
The time when the certificate was created in RFC 3339 format, for example
2012-11-15T16:19:00.094ZCorresponds to the JSON propertycreateTime. -
#expiration_time ⇒ String
The time when the certificate expires in RFC 3339 format, for example
2012-11-15T16:19:00.094Z. -
#instance ⇒ String
Name of the database instance.
-
#kind ⇒ String
This is always
sql#sslCert. -
#self_link ⇒ String
The URI of this resource.
-
#sha1_fingerprint ⇒ String
Sha1 Fingerprint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCert
constructor
A new instance of SslCert.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCert
Returns a new instance of SslCert.
6162 6163 6164 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cert ⇒ String
PEM representation.
Corresponds to the JSON property cert
6118 6119 6120 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6118 def cert @cert end |
#cert_serial_number ⇒ String
Serial number, as extracted from the certificate.
Corresponds to the JSON property certSerialNumber
6123 6124 6125 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6123 def cert_serial_number @cert_serial_number end |
#common_name ⇒ String
User supplied name. Constrained to [a-zA-Z.-_ ]+.
Corresponds to the JSON property commonName
6128 6129 6130 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6128 def common_name @common_name end |
#create_time ⇒ String
The time when the certificate was created in RFC 3339 format, for example 2012-11-15T16:19:00.094Z
Corresponds to the JSON property createTime
6134 6135 6136 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6134 def create_time @create_time end |
#expiration_time ⇒ String
The time when the certificate expires in RFC 3339 format, for example 2012-11-15T16:19:00.094Z.
Corresponds to the JSON property expirationTime
6140 6141 6142 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6140 def expiration_time @expiration_time end |
#instance ⇒ String
Name of the database instance.
Corresponds to the JSON property instance
6145 6146 6147 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6145 def instance @instance end |
#kind ⇒ String
This is always sql#sslCert.
Corresponds to the JSON property kind
6150 6151 6152 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6150 def kind @kind end |
#self_link ⇒ String
The URI of this resource.
Corresponds to the JSON property selfLink
6155 6156 6157 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6155 def self_link @self_link end |
#sha1_fingerprint ⇒ String
Sha1 Fingerprint.
Corresponds to the JSON property sha1Fingerprint
6160 6161 6162 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6160 def sha1_fingerprint @sha1_fingerprint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6167 6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6167 def update!(**args) @cert = args[:cert] if args.key?(:cert) @cert_serial_number = args[:cert_serial_number] if args.key?(:cert_serial_number) @common_name = args[:common_name] if args.key?(:common_name) @create_time = args[:create_time] if args.key?(:create_time) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @instance = args[:instance] if args.key?(:instance) @kind = args[:kind] if args.key?(:kind) @self_link = args[:self_link] if args.key?(:self_link) @sha1_fingerprint = args[:sha1_fingerprint] if args.key?(:sha1_fingerprint) end |