Class: Google::Apis::SqladminV1::SslCertsInsertResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

SslCert insert response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertsInsertResponse

Returns a new instance of SslCertsInsertResponse.



6277
6278
6279
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6277

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_certGoogle::Apis::SqladminV1::SslCertDetail

SslCertDetail. Corresponds to the JSON property clientCert



6258
6259
6260
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6258

def client_cert
  @client_cert
end

#kindString

This is always sql#sslCertsInsert. Corresponds to the JSON property kind

Returns:

  • (String)


6263
6264
6265
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6263

def kind
  @kind
end

#operationGoogle::Apis::SqladminV1::Operation

An Operation resource. For successful operations that return an Operation resource, only the fields relevant to the operation are populated in the resource. Corresponds to the JSON property operation



6270
6271
6272
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6270

def operation
  @operation
end

#server_ca_certGoogle::Apis::SqladminV1::SslCert

SslCerts Resource Corresponds to the JSON property serverCaCert



6275
6276
6277
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6275

def server_ca_cert
  @server_ca_cert
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6282
6283
6284
6285
6286
6287
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6282

def update!(**args)
  @client_cert = args[:client_cert] if args.key?(:client_cert)
  @kind = args[:kind] if args.key?(:kind)
  @operation = args[:operation] if args.key?(:operation)
  @server_ca_cert = args[:server_ca_cert] if args.key?(:server_ca_cert)
end