Class: Google::Apis::SqladminV1::User
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1::User
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb
Overview
A Cloud SQL user resource.
Instance Attribute Summary collapse
-
#database_roles ⇒ Array<String>
Optional.
-
#dual_password_type ⇒ String
Dual password status for the user.
-
#etag ⇒ String
This field is deprecated and will be removed from a future version of the API.
-
#host ⇒ String
Optional.
-
#iam_email ⇒ String
Optional.
-
#iam_status ⇒ String
Indicates if a group is active or inactive for IAM database authentication.
-
#instance ⇒ String
The name of the Cloud SQL instance.
-
#kind ⇒ String
This is always
sql#user. -
#name ⇒ String
The name of the user in the Cloud SQL instance.
-
#password ⇒ String
The password for the user.
-
#password_policy ⇒ Google::Apis::SqladminV1::UserPasswordValidationPolicy
User level password validation policy.
-
#project ⇒ String
The project ID of the project containing the Cloud SQL database.
-
#server_roles ⇒ Array<String>
Optional.
-
#sqlserver_user_details ⇒ Google::Apis::SqladminV1::SqlServerUserDetails
Represents a Sql Server user on the Cloud SQL instance.
-
#type ⇒ String
The user type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ User
constructor
A new instance of User.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ User
Returns a new instance of User.
6776 6777 6778 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6776 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database_roles ⇒ Array<String>
Optional. Role memberships of the user
Corresponds to the JSON property databaseRoles
6694 6695 6696 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6694 def database_roles @database_roles end |
#dual_password_type ⇒ String
Dual password status for the user.
Corresponds to the JSON property dualPasswordType
6699 6700 6701 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6699 def dual_password_type @dual_password_type end |
#etag ⇒ String
This field is deprecated and will be removed from a future version of the API.
Corresponds to the JSON property etag
6704 6705 6706 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6704 def etag @etag end |
#host ⇒ String
Optional. The host from which the user can connect. For insert operations,
host defaults to an empty string. For update operations, host is specified
as part of the request URL. The host name cannot be updated after insertion.
For a MySQL instance, it's required; for a PostgreSQL or SQL Server instance,
it's optional.
Corresponds to the JSON property host
6713 6714 6715 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6713 def host @host end |
#iam_email ⇒ String
Optional. The full email for an IAM user. For normal database users, this will
not be filled. Only applicable to MySQL database users.
Corresponds to the JSON property iamEmail
6719 6720 6721 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6719 def iam_email @iam_email end |
#iam_status ⇒ String
Indicates if a group is active or inactive for IAM database authentication.
Corresponds to the JSON property iamStatus
6724 6725 6726 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6724 def iam_status @iam_status end |
#instance ⇒ String
The name of the Cloud SQL instance. This does not include the project ID. Can
be omitted for update because it is already specified on the URL.
Corresponds to the JSON property instance
6730 6731 6732 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6730 def instance @instance end |
#kind ⇒ String
This is always sql#user.
Corresponds to the JSON property kind
6735 6736 6737 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6735 def kind @kind end |
#name ⇒ String
The name of the user in the Cloud SQL instance. Can be omitted for update
because it is already specified in the URL.
Corresponds to the JSON property name
6741 6742 6743 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6741 def name @name end |
#password ⇒ String
The password for the user.
Corresponds to the JSON property password
6746 6747 6748 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6746 def password @password end |
#password_policy ⇒ Google::Apis::SqladminV1::UserPasswordValidationPolicy
User level password validation policy.
Corresponds to the JSON property passwordPolicy
6751 6752 6753 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6751 def password_policy @password_policy end |
#project ⇒ String
The project ID of the project containing the Cloud SQL database. The Google
apps domain is prefixed if applicable. Can be omitted for update because it
is already specified on the URL.
Corresponds to the JSON property project
6758 6759 6760 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6758 def project @project end |
#server_roles ⇒ Array<String>
Optional. The server roles for the SQL Server login.
Corresponds to the JSON property serverRoles
6763 6764 6765 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6763 def server_roles @server_roles end |
#sqlserver_user_details ⇒ Google::Apis::SqladminV1::SqlServerUserDetails
Represents a Sql Server user on the Cloud SQL instance.
Corresponds to the JSON property sqlserverUserDetails
6768 6769 6770 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6768 def sqlserver_user_details @sqlserver_user_details end |
#type ⇒ String
The user type. It determines the method to authenticate the user during login.
The default is the database's built-in user type.
Corresponds to the JSON property type
6774 6775 6776 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6774 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6781 6782 6783 6784 6785 6786 6787 6788 6789 6790 6791 6792 6793 6794 6795 6796 6797 |
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6781 def update!(**args) @database_roles = args[:database_roles] if args.key?(:database_roles) @dual_password_type = args[:dual_password_type] if args.key?(:dual_password_type) @etag = args[:etag] if args.key?(:etag) @host = args[:host] if args.key?(:host) @iam_email = args[:iam_email] if args.key?(:iam_email) @iam_status = args[:iam_status] if args.key?(:iam_status) @instance = args[:instance] if args.key?(:instance) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @password = args[:password] if args.key?(:password) @password_policy = args[:password_policy] if args.key?(:password_policy) @project = args[:project] if args.key?(:project) @server_roles = args[:server_roles] if args.key?(:server_roles) @sqlserver_user_details = args[:sqlserver_user_details] if args.key?(:sqlserver_user_details) @type = args[:type] if args.key?(:type) end |