Class: Google::Apis::SqladminV1::User

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

A Cloud SQL user resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ User

Returns a new instance of User.



6652
6653
6654
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_rolesArray<String>

Optional. Role memberships of the user Corresponds to the JSON property databaseRoles

Returns:

  • (Array<String>)


6575
6576
6577
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6575

def database_roles
  @database_roles
end

#dual_password_typeString

Dual password status for the user. Corresponds to the JSON property dualPasswordType

Returns:

  • (String)


6580
6581
6582
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6580

def dual_password_type
  @dual_password_type
end

#etagString

This field is deprecated and will be removed from a future version of the API. Corresponds to the JSON property etag

Returns:

  • (String)


6585
6586
6587
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6585

def etag
  @etag
end

#hostString

Optional. The host from which the user can connect. For insert operations, host defaults to an empty string. For update operations, host is specified as part of the request URL. The host name cannot be updated after insertion. For a MySQL instance, it's required; for a PostgreSQL or SQL Server instance, it's optional. Corresponds to the JSON property host

Returns:

  • (String)


6594
6595
6596
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6594

def host
  @host
end

#iam_emailString

Optional. The full email for an IAM user. For normal database users, this will not be filled. Only applicable to MySQL database users. Corresponds to the JSON property iamEmail

Returns:

  • (String)


6600
6601
6602
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6600

def iam_email
  @iam_email
end

#iam_statusString

Indicates if a group is active or inactive for IAM database authentication. Corresponds to the JSON property iamStatus

Returns:

  • (String)


6605
6606
6607
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6605

def iam_status
  @iam_status
end

#instanceString

The name of the Cloud SQL instance. This does not include the project ID. Can be omitted for update because it is already specified on the URL. Corresponds to the JSON property instance

Returns:

  • (String)


6611
6612
6613
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6611

def instance
  @instance
end

#kindString

This is always sql#user. Corresponds to the JSON property kind

Returns:

  • (String)


6616
6617
6618
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6616

def kind
  @kind
end

#nameString

The name of the user in the Cloud SQL instance. Can be omitted for update because it is already specified in the URL. Corresponds to the JSON property name

Returns:

  • (String)


6622
6623
6624
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6622

def name
  @name
end

#passwordString

The password for the user. Corresponds to the JSON property password

Returns:

  • (String)


6627
6628
6629
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6627

def password
  @password
end

#password_policyGoogle::Apis::SqladminV1::UserPasswordValidationPolicy

User level password validation policy. Corresponds to the JSON property passwordPolicy



6632
6633
6634
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6632

def password_policy
  @password_policy
end

#projectString

The project ID of the project containing the Cloud SQL database. The Google apps domain is prefixed if applicable. Can be omitted for update because it is already specified on the URL. Corresponds to the JSON property project

Returns:

  • (String)


6639
6640
6641
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6639

def project
  @project
end

#sqlserver_user_detailsGoogle::Apis::SqladminV1::SqlServerUserDetails

Represents a Sql Server user on the Cloud SQL instance. Corresponds to the JSON property sqlserverUserDetails



6644
6645
6646
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6644

def sqlserver_user_details
  @sqlserver_user_details
end

#typeString

The user type. It determines the method to authenticate the user during login. The default is the database's built-in user type. Corresponds to the JSON property type

Returns:

  • (String)


6650
6651
6652
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6650

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6657

def update!(**args)
  @database_roles = args[:database_roles] if args.key?(:database_roles)
  @dual_password_type = args[:dual_password_type] if args.key?(:dual_password_type)
  @etag = args[:etag] if args.key?(:etag)
  @host = args[:host] if args.key?(:host)
  @iam_email = args[:iam_email] if args.key?(:iam_email)
  @iam_status = args[:iam_status] if args.key?(:iam_status)
  @instance = args[:instance] if args.key?(:instance)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @password = args[:password] if args.key?(:password)
  @password_policy = args[:password_policy] if args.key?(:password_policy)
  @project = args[:project] if args.key?(:project)
  @sqlserver_user_details = args[:sqlserver_user_details] if args.key?(:sqlserver_user_details)
  @type = args[:type] if args.key?(:type)
end