Class: Google::Apis::SqladminV1::User

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1/classes.rb,
lib/google/apis/sqladmin_v1/representations.rb,
lib/google/apis/sqladmin_v1/representations.rb

Overview

A Cloud SQL user resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ User

Returns a new instance of User.



6585
6586
6587
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_rolesArray<String>

Optional. Role memberships of the user Corresponds to the JSON property databaseRoles

Returns:

  • (Array<String>)


6508
6509
6510
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6508

def database_roles
  @database_roles
end

#dual_password_typeString

Dual password status for the user. Corresponds to the JSON property dualPasswordType

Returns:

  • (String)


6513
6514
6515
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6513

def dual_password_type
  @dual_password_type
end

#etagString

This field is deprecated and will be removed from a future version of the API. Corresponds to the JSON property etag

Returns:

  • (String)


6518
6519
6520
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6518

def etag
  @etag
end

#hostString

Optional. The host from which the user can connect. For insert operations, host defaults to an empty string. For update operations, host is specified as part of the request URL. The host name cannot be updated after insertion. For a MySQL instance, it's required; for a PostgreSQL or SQL Server instance, it's optional. Corresponds to the JSON property host

Returns:

  • (String)


6527
6528
6529
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6527

def host
  @host
end

#iam_emailString

Optional. The full email for an IAM user. For normal database users, this will not be filled. Only applicable to MySQL database users. Corresponds to the JSON property iamEmail

Returns:

  • (String)


6533
6534
6535
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6533

def iam_email
  @iam_email
end

#iam_statusString

Indicates if a group is active or inactive for IAM database authentication. Corresponds to the JSON property iamStatus

Returns:

  • (String)


6538
6539
6540
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6538

def iam_status
  @iam_status
end

#instanceString

The name of the Cloud SQL instance. This does not include the project ID. Can be omitted for update because it is already specified on the URL. Corresponds to the JSON property instance

Returns:

  • (String)


6544
6545
6546
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6544

def instance
  @instance
end

#kindString

This is always sql#user. Corresponds to the JSON property kind

Returns:

  • (String)


6549
6550
6551
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6549

def kind
  @kind
end

#nameString

The name of the user in the Cloud SQL instance. Can be omitted for update because it is already specified in the URL. Corresponds to the JSON property name

Returns:

  • (String)


6555
6556
6557
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6555

def name
  @name
end

#passwordString

The password for the user. Corresponds to the JSON property password

Returns:

  • (String)


6560
6561
6562
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6560

def password
  @password
end

#password_policyGoogle::Apis::SqladminV1::UserPasswordValidationPolicy

User level password validation policy. Corresponds to the JSON property passwordPolicy



6565
6566
6567
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6565

def password_policy
  @password_policy
end

#projectString

The project ID of the project containing the Cloud SQL database. The Google apps domain is prefixed if applicable. Can be omitted for update because it is already specified on the URL. Corresponds to the JSON property project

Returns:

  • (String)


6572
6573
6574
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6572

def project
  @project
end

#sqlserver_user_detailsGoogle::Apis::SqladminV1::SqlServerUserDetails

Represents a Sql Server user on the Cloud SQL instance. Corresponds to the JSON property sqlserverUserDetails



6577
6578
6579
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6577

def sqlserver_user_details
  @sqlserver_user_details
end

#typeString

The user type. It determines the method to authenticate the user during login. The default is the database's built-in user type. Corresponds to the JSON property type

Returns:

  • (String)


6583
6584
6585
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6583

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6590
6591
6592
6593
6594
6595
6596
6597
6598
6599
6600
6601
6602
6603
6604
6605
# File 'lib/google/apis/sqladmin_v1/classes.rb', line 6590

def update!(**args)
  @database_roles = args[:database_roles] if args.key?(:database_roles)
  @dual_password_type = args[:dual_password_type] if args.key?(:dual_password_type)
  @etag = args[:etag] if args.key?(:etag)
  @host = args[:host] if args.key?(:host)
  @iam_email = args[:iam_email] if args.key?(:iam_email)
  @iam_status = args[:iam_status] if args.key?(:iam_status)
  @instance = args[:instance] if args.key?(:instance)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @password = args[:password] if args.key?(:password)
  @password_policy = args[:password_policy] if args.key?(:password_policy)
  @project = args[:project] if args.key?(:project)
  @sqlserver_user_details = args[:sqlserver_user_details] if args.key?(:sqlserver_user_details)
  @type = args[:type] if args.key?(:type)
end